#include <htc.h>
#include <pic18f65k22.h>
#include "defs.h"
#include "timers.h"
#include "Interrupts.h"
#include "mains.h"
#include "Port_Pins.h"
#include "peripherals.h"

/****
 Interrupt Settings for Hi-Tech Compiler.
 * Always turn ON IPEN (RCON Register Bit) which is to Enable Priority Level Interrupts
 * There are two types of Interrupts in PIC.
 * 1. High Priority Interrupts
 * 2. Low Priority Interrupts
 * Each Interrupt can be defined as Low/High Priority in their control registers.
 * There are flags GIEH/GIE (INTCON Register)& GIEL/PEIE (INTCON register). When GIEH/GIE = 1, it allows all High Priority interrupts Enabled
 * When GIEL/PEIE is enabled, it enables all low priority Interrupts.
 *
 * Now to write the suboroutine for High Priority interrupts WE MUST USE following format
 * void interrupt high_int (void) where high_int can be any name what we like
 *
 * for Low Priority Interrupts
 * void interrupt low_priority lo_int (void) where lo_int can be any name what we like

 */
void    timer0_settings (void);


void    interrupts_settings (void)
{
    IPEN = 1; //enable priority levels in interrupts
    GIE_GIEH = 0;//disable any interrupt in the beginning
    PEIE_GIEL = 0; //disable low priority and peripheral interrupts
    INT0IE = 0; //disable external interrupt
    INT0IF = 0; //clear the external interrupt flag.
    RBIE = 0; //disable the RB port change interrupt
    RBIF = 0;   //clear the RB port change interrupt flag
    timer0_settings (); //set timer 0 interrupt


    /**INTCON2 Settings**/
    nRBPU =0;//disabling for testing purposes 0 ; //Enable Pull-Ups on PortB
    RDPU = 1; //disable the internal pull ups
    REPU = 1;
    INTEDG0 = 1 ;// Interrupt on rising edge
    INTEDG1 =  1; //Interrupt on rising Edge
    INTEDG2 = 1; //Interrupt on rising Edge
    INTEDG3 = 1;
    INT3IP = 0;
    RBIP = 0;
    //disable all other interrupts and set as low priority.
    INTCON3 = 0;
    PIR1 = 0;
    PIR2 = 0;
    PIR3 = 0;
    PIR4 = 0;
    PIR5 = 0;
    PIR6 = 0;
    PIE1 = 0;
    PIE2 = 0;
    PIE3 = 0;
    PIE4 = 0;
    PIE5 = 0;
    PIE6 = 0;
    IPR1 = 0;
    IPR2 = 0;
    IPR3 = 0;
    IPR4 = 0;
    IPR5 = 0;
    IPR6 = 0;
   // external_interrupt_enable ();
    interrupts_disable();




}

void    external_interrupt_enable (void)
{
    RB0 = 1;
    INT0IF = 0;


    INTEDG0 = 0;


    INT3IP = 1;
    rtcc_5_sec_interrupt ();//turn on ALarm with RTCC with 5 second
    Sleep_Port_Pins ();//before we go to sleep set all the port pins to minimize the current consumption
    
    INT0IE = 1;


}
void    external_interrupt_disable(void)
{
    RB0 = 1;
    INT0IF = 0;
    INT1IF = 0;
    INT2IF = 0;
    INT3IF = 0;

    INT0IE = 0;
    INT1IE = 0;
    INT2IE = 0;
    INT3IE = 0;
    rtcc_disable();
   Port_Pins_Initialization ();    //put back all the portpins as it should be

}

void    rtcc_5_sec_interrupt (void)
{
    CLRWDT();
   
    RTCCMD = 0;  //enable the clock source to the module
   
   rtcc_reg_unlock();  //unlock the rtcc register
    ALRMEN = 0;
    RTCCMD = 0;  //enable the clock source to the module
    CHIME = 0;
    RTCSYNC = 0;
    
    AMASK3 = 0;//AMASK = 0010 for every 10 seconds
    AMASK2 = 0;
    AMASK1 = 1;
    AMASK0 = 0;

    RTCCAL = 0;
    RTCEN = 1;

    RTSECSEL0 = 0;
    RTSECSEL1 = 1;

    RTCOE = 1;
     /**the following sequence must be followed.*/
   RTCPTR0 = 1;
   RTCPTR1 = 1;
   RTCVAL = 0x0014;// reserve reserve year year
   RTCVAL = 0x0101;// ,month month dayday
   RTCVAL = 0x0101;//weekday weekday hours hours
   RTCVAL = 0x0000;//minutes minutes seconds seconds
     //*****************************
    /**the following sequence must be followed.*/
   ALRMPTR0 = 0;
   ALRMPTR1 = 1;
   ALRMVAL = 0x0101;// ,month month dayday
   ALRMVAL = 0x0101;//weekday weekday hours hours
   ALRMVAL = 0x0005;//minutes minutes seconds seconds
    //*****************************

   ALRMRPT = 0; //no repetition
   ALRMEN = 1;  //enable alarm
   RTCCIF = 0;  //clear the interrupt flag
   RTCCIE = 0; //disable the interrupt enable bit
   RTCCIP = 0; //low priority for the interrupt
   RTCCMD = 1;  //enable the clock source to the module
   RTCCIE = 1; //enable the interrupt enable bit
   ALRMEN = 1;//enable the alarm
   RTCCMD = 0;  //enable the clock source to the module
  
   
   rtcc_reg_lock();

   //RTCEN = 1; //Enable the Real Time clock and calender
PEIE_GIEL = 1;//enable the peripheral interrupts

}

void    rtcc_disable (void)
{
    CLRWDT();
    ALRMEN = 0;
   
    rtcc_reg_unlock();
    RTCCIE = 0; //disable the interrupt enable bit
    
    rtcc_reg_lock();
}
void    timer0_settings (void)
{
    TMR0IF = 0; //clear the timer 0 interrupt flag
    TMR0IP = 1; //set timer0 as high priority interrupt
    timers_init (); //set the timer 0 values
    TMR0IE = 1; //enable the timer 0 interrupt
}

void    interrupts_disable (void)
{

    GIE_GIEH = 0;
    PEIE_GIEL = 0;
    TMR0IF = 0;//clear the interrupt flag
    TMR0IE = 0; //disable the timer0 interrupt
}

void    interrupts_enable (void)
{
    TMR0IE = 1;
    timers_reset(); //reset the timer
    GIE_GIEH = 1;   //
}

void    interrupt    tmr0(void)    //when a high priority interrupt occurs, we come here
{
    GIE_GIEH = 0;    //disable all high priority interrupts when we are serving the interrupt
   

    if (INT0IF)
    {
        RB0 = 1;
        SPEED = 2;
        SLEEP_TIMER = 250;
        INT0IF = 0;
        INT0IE = 0;
        external_interrupt_disable ();
        

    }
  
    else if (TMR0IF)
    {
        TMR0IF = 0;
        TMR0IE = 0;
        timers_ISR ();      //do timer interrupt routine
       
        TMR0IF = 0;
        TMR0IE = 1;
    }

    PEIE_GIEL = 1;
    GIE_GIEH = 1;    //after timer interrupt served, enable all interrupts


}

void    interrupt low_priority Wake_Up_call (void)
{
   GIE_GIEH = 0;
    if (RTCCIF)
    {
        ALRMEN = 0;//disable the alarm
        PEIE_GIEL = 0;
        RTCCIF = 0;
        
         external_interrupt_disable ();
       

    }

     PEIE_GIEL = 1;
    GIE_GIEH = 1;    //after timer interrupt served, enable all interrupts

}
