#include <htc.h>
#include "pic18f65k22.h"
#include "Port_Pins.h"
#include "defs.h"

/****************

 Pin Number     Micro Description       Function
 * 1                 RE1                Clock -AS Chip  Pin 30
 * 2                 RE0                DI - AS chip 29
 * 3                 RG0                XCS - AS Chip 28
 * 4                 RG1                Analogue Switch - Speech Synthesis 1 = Speech Synthesis in the Speaker, 0 = Audio
 * 5                 RG2                AS Chip ONLINE/OFFLINE 1=ONLINE, 0 = OFFLINE
 * 6                 RG3                CP Detect
 * 7                 MCLR/RG5
 * 8                 RG4                Not Used
 * 9                 VSS
 * 10                VDDCORE            VDD+CAP
 * 11                RF7                "DV" =- Valid Data Strobe Pin 15 DTMF
 * 12                RF6                "D3" = Pin 14 DTMF
 * 13                RF5                "D2" Pin 13 of DTMF
 * 14                RF4                "D1" Pin 12 of DTMF
 * 15                RF3                "D0" Pin 11 of DTMF
 * 16                RF2                Test Pin
 * 17                RF1                "NO-AC" on AS Chip Circuit. 0 = When Pulse Dialling
 * 18                ENVREG             VDD to sue internal regulator
 * 19                VDD
 * 20                VSS
 * 21                RA3                Trigger 0 = Pushed
 * 22                RA2                Not Used
 * 23                RA1                LED2/Green Pictogram 0 = OFF, 1 = ON
 * 24                RA0                LED3/Yellow Pictogram 0 = OFF, 1 = ON
 * 25                VSS
 * 26                VDD
 * 27                RA5                Not Used
 * 28                RA4                Not Used
 * 29                RC1                Not Used
 * 30                RC0                Not Used
 * 31                RC6                Opto LED Drive - Output of the Opto goes to Pin 4 of RS485
 * 32                RC7                Output from the Opto. OPTO controlled by Pin 1 of RS485
 * 33                RC2                Pin 5 of Keypad (PTS) (On the PCB "SWC" - We refer as Pin 1)
 * 34                RC3                Pin 4 of Keypad (TCS)
 * 35                RC4                Pin 3 of Keypad (MRS)
 * 36                RC5                Pin 2 of Keypad (AS)
 * 37                RB7                PGD
 * 38                VDD
 * 39                OSC1
 * 40                OSC2
 * 41                VSS
 * 42                RB6                PGC
 * 43                RB5                Pin 6 of Keypad (CS)
 * 44                RB4                Pin 7 of Keypad
 * 45                RB3                Pin 8 of Keypad
 * 46                RB2                Pin 9 of Keypad
 * 47                RB1                Pin 10 of Keypad
 * 48                RB0                Pin 11 of Keypad
 * 49                RD7                Pin 12 of Keypad
 * 50                RD6                RS485 Control
 * 51                RD5                LED Drive for Opto to control output ("g")
 * 52                RD4                LED Drive for Opto to control output ("d")
 * 53                RD3                Flashing LED on the Board to confirm the Micro is working
 * 54                RD2                Test Point T2
 * 55                RD1                No connection
 * 56                VSS
 * 57                VDD
 * 58                RD0                No Connection
 * 59                RE7                LED Drive for Opto to control output ("c")
 * 60                RE6                Pin 2 of ISD - MOSI Data
 * 61                RE5                Pin 1 of ISD - SS (Chip Select)
 * 62                RE4                Pin 28 of ISD - CLK
 * 63                RE3                Pin 1 of Audio Amp - Chip Enable 0 = Shutdown, 1 = Working
 * 64                RE2                Pin 5 of Analogue Switch "DCU2" Normal State -Handset Microphone, Switched - to put Speech Synthesis Online




******/

void Port_Pins_Initialization (void) // this subroutine only puts the relevant pins as input or output.
//the high/low status initialization will be in the relevant initialization file. i.e. for keypad, it will be on keypad.c file
{
    
    
   TRISA = 0xff;
    TRISB = 0xff;
    TRISC = 0xff;
    TRISD0 = 1;
    TRISD1 = 1;
    TRISD2 = 1;
    TRISD3 = 0;
    TRISD4 = 1;
    TRISD5 = 1;
    TRISD6 = 1;
    TRISD7 = 1;
    TRISE = 0xff;
    TRISF = 0xff;
    TRISG = 0xff;

    PORTA = 0xff;
    PORTB = 0xff;
    PORTC = 0xff;;
    PORTD = 0xff;
    PORTF = 0xff;
    PORTG = 0xff;

    LATA = 0;
    LATB = 0;
    LATC = 0;
    LATD = 0;
    LATE = 0;
    LATF = 0;
    LATG = 0;


 
          //it is good practice to write 1 on all the port pins and 0 on all the latches. it will keep all the i/ps as High and Latches as 0.

   
    // REPU = 1; //set as internal pull ups on Port E.

    TRISD3 = 0;   // Test LED
    TRISD2 = 1; //TEST Pin


    //for Keypad
    TRISC3 = 1;
    TRISC4 = 1;
    TRISC5 = 1;

          TRISC2 = 0;//FOR SLEEP MODE TEST WE ARE MAKING IT AS AN OUTPUT 1;    //ALL I/PS
         TRISB5 = 1;
         TRISB4 = 1;
         TRISB3 = 1;
         TRISB2 = 1;   
        TRISB1 = 1;
        TRISB0 = 1;
         TRISD7 = 1;
   
     // For AS2522B Chip

                TRISE0 = 0; //output
                TRISE1 = 0; //output
                TRISG0 = 0;//OUTPUT
                TRISG2 = 0;//output
                TRISG1 = 0;//output
                TRISE3 = 0;
                TRISE2 = 0;


     // For ISD Chip

         TRISE4 = 1;//SET THE RELEVANT PORTS AS I/Ps AS WE DON'T USE THEM
         TRISE5 = 1;
         TRISE6 = 1;

     // For DTMF Detection
         TRISF6 = 1; //Make as input
         TRISF5 = 1;
         TRISF4 = 1;
         TRISF3 = 1;
	 TRISF7 = 1;

     //For Others

         TRISG3 = 1;// Call Progress Input
         TRISF2 = 0;//1; //Test Pin as I/P NOT USING
         TRISF1 = 1; //AS AN I/P NOT USED For Pulse dialling
         TRISA3 = 1;// Trigger

         TRISA1 = 0;//               LED2/Green Pictogram 0 = OFF, 1 = ON
         TRISA0 = 0;//                LED3/Yellow Pictogram 0 = OFF, 1 = ON
         //ALL OF THE FOLLOWING SET AS I/P BECAUSE NOT USED
         TRISC6 = 1;//                Opto LED Drive - Output of the Opto goes to Pin 4 of RS485
         TRISC7 = 1;//               Output from the Opto. OPTO controlled by Pin 1 of RS485
         TRISD6 = 1;// RS485 Control
         TRISD5 = 1;//                LED Drive for Opto to control output ("g")
         TRISD4 = 1;//                LED Drive for Opto to control output ("d")
         TRISE7 = 1;//                LED Drive for Opto to control output ("c")
      
         //Making all Pins which we do not use as inputs

         TRISA2 = 1;
         TRISA5 = 1;//                Not Used
         TRISA4 = 1;//               Not Used
         TRISC1 = 1;//               Not Used
         TRISC0 = 1;//               Not Used
         TRISD1 = 1;
         TRISD0 = 1;
         TRISB6 = 1;//
         TRISB7 = 1;

         //it is good practice to write 1 on all the port pins and 0 on all the latches. it will keep all the i/ps as High and Latches as 0.

    PORTA = 0xff;
    PORTB = 0xff;
    PORTC = 0xff;;
    PORTD = 0xff;
    PORTF = 0xff;
    PORTG = 0xff;

    
    LATA = 0;
    LATB = 0;
    LATC = 0;
    LATD = 0;
    LATE = 0;
    LATF = 0;
    LATG = 0;
    
    LATE0 = 1;
    LATE1 = 1;
    LATG0 = 1;
    LATG2 = 1;

    RB0 = 1;
/*****
    
    
    LATG1 = 1;
    LATE3 = 1;
    LATE2 = 1;
   // LATA1 = 1;
    LATA0 = 1;
   
******/
 
        


}

void Sleep_Port_Pins (void)
{
    TRISA = 0x00;
    TRISB = 0x00;
    TRISB0 = 1; //this is the interrupt to wake up the micro so keep that as an input.
    TRISC = 0x00;
    TRISE = 0x00;
    TRISF = 0x00;
    TRISG = 0x00;

    PORTA = 0xff;
    LATA = 0xff;
    LATB1 = 0;

    LATB2 = 1;
    LATB3 = 1;
    LATB4 = 1;
    LATB5 = 1;
    LATB6 = 1;
    LATB7 = 1;


    LATC0 = 1;
    LATC1 = 1;
    SLEEP_TEST = 0;//0;
    LATC3 = 1;
    LATC4 = 1;
    LATC5 = 1;
    LATC6 = 1;
    LATC7 = 1;
    LATD = 0xff;
    LATF = 0xff;
    LATE = 0xff;
    LATG = 0xff;
    PORTC = 0xfb; // fb
    PORTD = 0xff;
    PORTE = 0xff;
    PORTF = 0xff;
    PORTG = 0xff;
}
