/* 
 * File:   Port_Pins.h
 * Author: Mayur
 *From the Pic Micro's datasheet, they say to write on the port pin
 * use LAT register and to read the pin use PORT registers.
 * Therefore whichever pins are inputs we use PORT Registers and
 * whichever pins are output we use LAT register
 * Created on 28 April 2014, 08:00
 */

#ifndef PORT_PINS_H
#define	PORT_PINS_H
/****************


 Pin Number     Micro Description       Function
 * 1                 RE1                Clock -AS Chip  Pin 30
 * 2                 RE0                DI - AS chip 29
 * 3                 RG0                XCS - AS Chip 28
 * 4                 RG1                Default 0.Analogue Switch - Speech Synthesis 1 = Speech Synthesis in the Speaker, 0 = Audio
 * 5                 RG2                AS Chip ONLINE/OFFLINE 1=ONLINE, 0 = OFFLINE
 * 6                 RG3                I/P CP Detect
 * 7                 MCLR/RG5
 * 8                 RG4                Not Used
 * 9                 VSS
 * 10                VDDCORE            VDD+CAP
 * 11                RF7                "DV" =- Valid Data Strobe Pin 15 DTMF
 * 12                RF6                "D3" = Pin 14 DTMF
 * 13                RF5                "D2" Pin 13 of DTMF
 * 14                RF4                "D1" Pin 12 of DTMF
 * 15                RF3                "D0" Pin 11 of DTMF
 * 16                RF2                I/P Test Pin
 * 17                RF1                MAKE AS AN I/P "NO-AC" on AS Chip Circuit. 0 = When Pulse Dialling
 * 18                ENVREG             VDD to use internal regulator
 * 19                VDD
 * 20                VSS
 * 21                RA3                Trigger 0 = Pushed
 * 22                RA2                Not Used
 * 23                RA1                LED2/Green Pictogram 0 = OFF, 1 = ON
 * 24                RA0                LED3/Yellow Pictogram 0 = OFF, 1 = ON
 * 25                VSS
 * 26                VDD
 * 27                RA5                Not Used
 * 28                RA4                Not Used
 * 29                RC1                Not Used
 * 30                RC0                Not Used
 * 31                RC6              IP  Opto LED Drive - Output of the Opto goes to Pin 4 of RS485
 * 32                RC7              IP  Output from the Opto. OPTO controlled by Pin 1 of RS485
 * 33                RC2                Pin 5 of Keypad (PTS) (On the PCB "SWC" - We refer as Pin 1)
 * 34                RC3                Pin 4 of Keypad (TCS)
 * 35                RC4                Pin 3 of Keypad (MRS)
 * 36                RC5                Pin 2 of Keypad (AS)
 * 37                RB7                PGD
 * 38                VDD
 * 39                OSC1
 * 40                OSC2
 * 41                VSS
 * 42                RB6                PGC
 * 43                RB5                Pin 6 of Keypad (CS)
 * 44                RB4                Pin 7 of Keypad
 * 45                RB3                Pin 8 of Keypad
 * 46                RB2                Pin 9 of Keypad
 * 47                RB1                Pin 10 of Keypad
 * 48                RB0                Pin 11 of Keypad
 * 49                RD7                Pin 12 of Keypad
 * 50                RD6                I/P RS485 Control
 * 51                RD5                I/PLED Drive for Opto to control output ("g")
 * 52                RD4                I/P LED Drive for Opto to control output ("d")
 * 53                RD3                Flashing LED on the Board to confirm the Micro is working
 * 54                RD2                I/P Test Point T2
 * 55                RD1                No connection
 * 56                VSS
 * 57                VDD
 * 58                RD0                No Connection
 * 59                RE7               I/P LED Drive for Opto to control output ("c")
 * 60                RE6               I/P  Pin 2 of ISD - MOSI Data
 * 61                RE5               I/P Pin 1 of ISD - SS (Chip Select)
 * 62                RE4               I/P  Pin 28 of ISD - CLK
 * 63                RE3                Pin 1 of Audio Amp - Chip Enable 0 = Shutdown, 1 = Working
 * 64                RE2                Pin 5 of Analogue Switch "DCU2" Normal State -Handsfree Microphone, Switched - to put Speech Synthesis Online




******/

//  For 2 WAD Speaker we will use the following
#define TEST_LED    LATD3 // OUTPUT
#define TEST_PIN    RD2 // I/P
// For AS2522B Chip & Audio Control & Amplifier

#define	DI LATE0// LATE0    //;  //data input for as2522 chip
#define CLOCK LATE1//LATE1 // clock for as2522 chip
#define XCS LATG0    // chip select for as2522 chip
#define ONLINE  LATG2  //this is the transistor to put the ASCHIP ONLINE/OFFLINE
#define SPCH_SYNTH  LATG1   // to select betweeen Speech Synthesis and Audio in AS2522 Speaker
#define AUDIO_AMP   LATE3//                Pin 1 of Audio Amp - Chip Enable 0 = Shutdown, 1 = Working
#define SW_MIC      LATE2//                Pin 5 of Analogue Switch "DCU2" Normal State -Handsfree Microphone, Switched - to put Speech Synthesis Online


//For Keypad
//ALL INPUTS NO MATRIX SCANNING


#define  SLEEP_TEST      LATC2
#define  IP_PTS 	RC2 //PTS
#define  IP_CS  	RB5   // CS
#define  IP_7   	RB4
#define  IP_8   	RB3
#define  IP_9   	RB2
#define  IP_10   	RB1
#define  IP_11   	RB0
#define  IP_12   	RD7

#define TCS_BTN         RC3//                Pin 4 of Keypad (TCS)
#define MRS_BTN         RC4//                Pin 3 of Keypad (MRS)
#define AS_BTN          RC5//                Pin 2 of Keypad (AS)

// For HT9170 -DTMF Detection

#define		DTMF_Q4     RF6
#define 	DTMF_Q3     RF5
#define 	DTMF_Q2     RF4
#define		DTMF_Q1     RF3
#define		DTMF_STROBE RF7

// For ISD 4003 Chip
//ALL INPUTS. NOT REQUIRED

#define ISD_CS RE5
#define ISD_CLK RE4
#define ISD_MOSI RE6

//RS485
//ALL INPUTS NOT REQUIRED
#define DATA_OUT    RC6//              IP  Opto LED Drive - Output of the Opto goes to Pin 4 of RS485
#define DATA_IN     RC7//              IP  Output from the Opto. OPTO controlled by Pin 1 of RS485
#define DATA_DIR    RD6

//For Other Pins
#define CP_DETECT          RG3//I/P              CP Detect
#define TP_1    LATF2//RF2     //SETTING AS I/P NOT USED    Test Pin
#define PUL_DIAL  RF1// SETTING AS I/P NOT USED                "NO-AC" on AS Chip Circuit. 0 = When Pulse Dialling
#define TRIG       RA3//                Trigger 0 = Pushed
#define PIC_GREEN  LATA1   //             LED2/Green Pictogram 0 = OFF, 1 = ON
#define PIC_YELLOW LATA0   //             LED3/Yellow Pictogram 0 = OFF, 1 = ON
#define LED_G   RD5//SETTING AS I/P NOT USED LED DRIVE FOR OPTO TO CONTROL o/P G
#define LED_D   RD4//SETTING AS I/P NOT USED LED DRIVE FOR OPTO TO CONTROL o/P D
#define LED_C   RE7//SETTING AS I/P NOT USED LED Drive for Opto to control output ("c")



/*****
#define TEST_LED    LATD3
#define TEST_PIN    LATD2
// For AS2522B Chip & Audio Control & Amplifier

#define	DI LATE0// LATE0    //;  //data input for as2522 chip
#define CLOCK LATE1//LATE1 // clock for as2522 chip
#define XCS LATG0    // chip select for as2522 chip
#define ONLINE  LATG2  //this is the transistor to put the ASCHIP ONLINE/OFFLINE
#define SPCH_SYNTH  LATG1   // to select betweeen Speech Synthesis and Audio in AS2522 Speaker
#define AUDIO_AMP   LATE3//                Pin 1 of Audio Amp - Chip Enable 0 = Shutdown, 1 = Working
#define SW_MIC      LATE2//                Pin 5 of Analogue Switch "DCU2" Normal State -Handsfree Microphone, Switched - to put Speech Synthesis Online


//For Keypad

#define  KEY_RW1	LATC2 //PTS we are using the row as an output and column as an input to read the inputs
#define  KEY_RW2	LATB5   // CS therefore we have defined rows as an latch because we want to write and columns as ports to read
#define  KEY_RW3	LATB4
#define  KEY_RW4	LATB3
#define  KEY_COL4	RB2
#define  KEY_COL3 	RB1
#define  KEY_COL2 	RB0
#define  KEY_COL1 	RD7

#define TCS_BTN         RC3//                Pin 4 of Keypad (TCS)
#define MRS_BTN         RC4//                Pin 3 of Keypad (MRS)
#define AS_BTN          RC5//                Pin 2 of Keypad (AS)

// For HT9170 -DTMF Detection

#define		DTMF_Q4     RF6
#define 	DTMF_Q3     RF5
#define 	DTMF_Q2     RF4
#define		DTMF_Q1     RF3
#define		DTMF_STROBE RF7

// For ISD 4003 Chip

#define ISD_CS LATE5
#define ISD_CLK LATE4
#define ISD_MOSI LATE6

//RS485
#define DATA_OUT    LATC6//              IP  Opto LED Drive - Output of the Opto goes to Pin 4 of RS485
#define DATA_IN     RC7//              IP  Output from the Opto. OPTO controlled by Pin 1 of RS485
#define DATA_DIR    LATD6
//For Other Pins
#define CP_DETECT          RG3//                CP Detect
#define TP_1    LATF2     //    Test Pin
#define PUL_DIAL  LATF1//                "NO-AC" on AS Chip Circuit. 0 = When Pulse Dialling
#define TRIG       RA3//                Trigger 0 = Pushed
#define PIC_GREEN  LATA1   //             LED2/Green Pictogram 0 = OFF, 1 = ON
#define PIC_YELLOW LATA0   //             LED3/Yellow Pictogram 0 = OFF, 1 = ON
#define LED_G   LATD5//LED DRIVE FOR OPTO TO CONTROL o/P G
#define LED_D   LATD4//LED DRIVE FOR OPTO TO CONTROL o/P D
#define LED_C   LATE7//LED Drive for Opto to control output ("c")
******/
void Port_Pins_Initialization (void);
void Sleep_Port_Pins (void);

#endif	/* PORT_PINS_H */

