/***
 Timers
 * We are going to make the timer subroutine
 * with 2msec value

 */


#define     TMR0H_VALUE 255
#define     TMR0L_VALUE  121  //since our system clock is 1MHZ/4 = 250KHz = 0.000004 and
//our prescaler is 1:4, our timer will run at 256-121 = 125*4 = 2000usec = 2msec


#include <htc.h>
#include <pic18f65k22.h>
#include "Port_Pins.h"
#include    "timers.h"
#include    "defs.h"



UBYTE   TIMER_COUNTER;
UBYTE   SEQUENCE;
UBYTE   delay_timer;
UBYTE   timer_40msec;
UBYTE   del_beg;
UBYTE   timer_10msec;
UBYTE   timer_500msec;
UBYTE   LED_FLASH_NO;
UBYTE   MSEC_SEC;
UBYTE   SECOND_FLASH;
UBYTE   MSEC_2; //BECAUSE WE ARE USING 0.5MSEC TIMER WE NEED THIS TO HAVE THIS TO COUNT 2MSEC
bit     LED_FLASH;
bit     flag_40msec;
bit     DISPLAY_FLAG;
bit     DTMF_CHECK_FLAG;
bit     logic_input_f;
bit     flag_500msec;
bit     pin_1KHZ;
void timers_init (void)
{
    CLRWDT();
    TMR0ON = 0; //timer 0 off in the beginning because we don't want to start counting now.
    T08BIT = 1; //8 bit timer
    T0CS = 0; //source of the clock in internal/instruction clock
    T0SE = 0;//counter calculates on low to high transition
    PSA = 0; // timer0 prescaler is assigned
    /***
     
     Our frequency is 1 MHz so system clock will be 1/4 = 250KHz.
     once system cycle will get 0.000004 sec
     if 0.000004 second = 1 cycle. 0.002sec = 500 cycles
     Now that we have picked 1:4 as our prescaler so we need to count 500/4 = 125.
     to count 125 we need to load TMR0H as 121 because it will generate the interrupt when it will reach 256. i.e. 255 to 0
   ***/


    T0PS2 = 0;  // pre scaler value is 1:4
    T0PS1 = 0;
    T0PS0 = 1;
    TMR0H = TMR0H_VALUE;
    TMR0L = TMR0L_VALUE;

    MSEC_2 = 4;
    TIMER_COUNTER = 125;    //we will flash the LED at 250msec time
    SECOND_FLASH = 8;
    LED_FLASH = 0;
    logic_input_f = FALSE;
    MSEC_SEC = 25;
    SEQUENCE = 8;
    timer_40msec =20;
    DISPLAY_FLAG = FALSE;
    del_beg = 2;
    timer_10msec = 5;
    timer_500msec = 50;
    flag_500msec = FALSE;
    LED_FLASH_NO = 0;
    pin_1KHZ = 0;
    DTMF_CHECK_FLAG = FALSE;
}

void    timers_reset (void)
{
    CLRWDT();
    TMR0ON = 0; //stop timer 0
    TMR0IF = 0; //clear interrupt flag
    TMR0H = TMR0H_VALUE;    //reset the value
    TMR0L = TMR0L_VALUE;
    TMR0ON = 1; //re-start the timer.

}
void    timer_loop_2msec (void)
{
    CLRWDT();
     logic_input_f = TRUE;
 
    if (timer_40msec > 0)
    {
        timer_40msec--;
        if (timer_40msec == 0)
        {
            timer_40msec = 20;
            flag_40msec = TRUE;
            if (MSEC_SEC > 0)
            {
                MSEC_SEC--;
                if (MSEC_SEC == 0)
                {
                    MSEC_SEC = 25;
                    if (del_beg > 0)
                    {
                        del_beg--;
                    }
                
                }
            }
        }
    }


    if (timer_10msec > 0)
    {
        timer_10msec--;


        if (timer_10msec == 0)
        {

            timer_500msec--;
            if (timer_500msec == 0)
            {
                timer_500msec = 50;
                flag_500msec = TRUE;
            }
            timer_10msec = 5; //reload the timer
            DTMF_CHECK_FLAG = TRUE;
        }
    }

    if (TIMER_COUNTER > 0)
    {
      TIMER_COUNTER--;
       if (TIMER_COUNTER == 0)
       {
            TIMER_COUNTER = 125;
           
        
        }

    }
}
void    timers_ISR (void)   //when any time timer interrupt occurs, it must come here
{

    TMR0ON = 0;
    
    CLRWDT();

    
    timer_loop_2msec ();
     timers_reset ();

}