#include "htc.h"
#include "pic18f65k22.h"
#include <stdio.h>
#include <stdlib.h>
#include "defs.h"
#include "peripherals.h"

void    oscillator_settings (void);
void    wd_reg_settings (void); //for watchdog and regulator settings
void timer1_settings (void);
void timer2_settings (void);
void timer3_settings (void);
void timer4_settings (void);
void timer5_settings (void);
void timer6_settings (void);
void timer7_settings (void);
void timer8_settings (void);
void timer10_settings (void);
void    timer12_settings (void);
void    rtcc_settings (void);
void    ccp_settings (void);
void    ssp_settings (void);
void    a2d_settings (void);
void    comparator_settings(void);
void    hlvd_settings(void);
void    ctmu_settings (void);

void    peripherals_init (void)
{
    oscillator_settings();
    wd_reg_settings ();

    /*
     Disable all the peripherals. Compare module. Timers except Timer 0  UARTS, SSP, ADC, CTMU, RTCC, CCP,MSSP
     */
    PMD3 = 0xFF;
    PMD2 = 0xFF;
    rtcc_reg_unlock();  //unlock the rtcc register
    PMD1 = 0xFF;
    rtcc_reg_lock();
    
    PMD0 = 0xFF;

    //the following subroutines should not require according to datasheets because we have disabled the modules already via PMD registers
    timer1_settings ();
    timer2_settings ();
    timer3_settings ();
    timer4_settings ();
    timer5_settings ();
    timer6_settings ();
    timer7_settings ();
    timer8_settings ();
    timer10_settings ();
    timer12_settings ();
    rtcc_settings ();
    ccp_settings ();
    ssp_settings ();
    a2d_settings ();
    comparator_settings();
    hlvd_settings();
    ctmu_settings ();

}

void oscillator_settings (void)
{

   
    CLRWDT();
    
    IDLEN = 0;  //device enters sleep mode when SLEEP is executed


  //  SCS0 = 0;
  //  SCS1 = 0;
   
    /* OSCON settings
     IDLEN = 1; device enters an idle mode when sleep is executed
     * IRCF  011 for 1 MHZ frequency
     * SCS = 10 for Internal Frequency oscillator
     */

    SCS0 = 0;
    SCS1 = 1;
    IRCF0 = 1;
    IRCF1 = 1;
    IRCF2 = 0;

    /*
     OSCCON2 Settings
     * SOSCGO =0 ;
     * MFIOSEL = 0 - MFINTOSC is not used
     */

    SOSCGO = 0;//oscillator is not running when no source is requesting clocks. this allows to consume less current
    MFIOSEL = 0;

    /*
     OSCTUNE Settings
     * INTSRC = 0; 31KHz drives from LF-INTOSC
     * PLLEN = 0; PLL disbaled
     * TUN = 000000 Centre Frequency
     */

    PLLEN = 0;
    INTSRC = 0;//31KHz is derived from LF-INTOSC
    TUN0 = 0;
    TUN1 = 0;
    TUN2 = 0;
    TUN3 = 0;
    TUN4 = 0;
    TUN5 = 0;

    /*
     Reference Oscillator Control REFOCON
     * ROON = 0 reference oscillator output disabled
     * ROSEL = 1 HS is used as the base clock
     * RODIV = 0000 base clock value
     */

    ROSEL = 1;
    ROON = 0  ;
    RODIV0 = 0 ;
    RODIV1 = 0;
    RODIV2 = 0;
    RODIV3 = 0;


}

void    wd_reg_settings (void)
{
   
    SRETEN = 1;//regulator stays in ultra low power when goes into sleep mode.
    ULPEN = 0; // Ultra-Low Power wake up disabled

    CLRWDT();
    //watch dog is disabled
    CLRWDT();
    
}
void timer1_settings (void)
{
    CLRWDT();
    TMR1ON = 0;    //disable timer1, we do not need to do anything if this is disabled.
    TMR1CS0 = 0;   //use innstruction cycle as the clock for timer1
    TMR1CS1  = 0;

}

void    timer2_settings (void)
{
    CLRWDT();
    TMR2ON = 0;    //disable timer2, we do not need to do anything if this is disabled.
    T2CKPS0 = 1; //prescaler is 1:16 and post scaler is 1:16
    T2CKPS1 = 1;
    T2OUTPS0 = 1;
    T2OUTPS1 = 1 ;
    T2OUTPS2 = 1 ;
    T2OUTPS3  = 1;

}

void    timer3_settings (void)
{
    CLRWDT();
    TMR3ON = 0; //timer disabled


}

void    timer5_settings (void)
{
    CLRWDT();
    TMR5ON = 0; //timer disabled


}

void    timer7_settings (void)
{
    CLRWDT();
  

}

void    timer4_settings (void)
{
    CLRWDT();
    TMR4ON = 0; //timer disabled
}

void    timer6_settings (void)
{
    CLRWDT();
    TMR6ON = 0; //timer disabled
}

void    timer8_settings (void)
{
    CLRWDT();
    TMR8ON = 0; //timer disabled
}

void    timer10_settings (void)
{
    CLRWDT();

}

void    timer12_settings (void)
{
    CLRWDT();

}

void    rtcc_settings (void)
{
        CLRWDT();
        rtcc_reg_unlock();
        RTCEN = 0; //disable the Real Time clock and calender
        rtcc_reg_lock();
}



void    rtcc_reg_unlock (void)
{
        CLRWDT();
        asm("movlw 0x55");		// won't work in 'C'. Which idiot came up with this scheme?
        asm("movwf _EECON2");   //moves 0x55h in eecon2
   	asm("movlw 0xAA");  //moves 0xaa into w
	asm("movwf _EECON2"); //moves 0xAA into EECON2
	asm("movlw 0x20");  //mov 0x20 into w
	asm("bsf _RTCCFG,5"); //Enable RTCWREN

}

void    rtcc_reg_lock (void)
{
        CLRWDT();
        asm("movlw 0x55");		// won't work in 'C'. Which idiot came up with this scheme?
	asm("movwf _EECON2");
	asm("movlw 0xAA");
	asm("movwf _EECON2");
	asm("movlw 0x20");
	asm("bcf _RTCCFG,5"); //Disable RTCWREN
}



void    ccp_settings (void)
{
    CLRWDT();
    CCP4CON = 0x00; //disable all Capture/Compare/PWM modules.
    CCP5CON = 0x00;
    CCP6CON = 0x00;
    CCP7CON = 0x00;
    CCP8CON = 0x00;
  //  CCP9CON = 0x00;
  //  CCP10CON = 0x00;
    CCP1CON = 0x00;
    CCP2CON = 0x00;
    CCP3CON = 0x00;
    CCP4CON = 0x00;
}

void    ssp_settings (void)
{
    CLRWDT();
  

    
}

void    a2d_settings (void)
{
    CLRWDT();
    ADON = 0; //disable analogue to digital converter module
    ANCON0 = 0;
    ANCON1 = 0;
    ANCON2 = 0;
}

void    comparator_settings(void)
{
    CLRWDT();
  


    CVREN = 0; //CVref circuit is pwoered down
    CVROE = 0;
}

void    hlvd_settings   (void)
{
    CLRWDT();
    HLVDEN = 0; //disable high to low voltage detection circuit
}

void   ctmu_settings (void)
{

    CLRWDT();
    //charge time measurement unit is disabled
    CTMUEN = 0;
    TGEN = 0;
    EDGEN = 0;
    EDGSEQEN = 0;
    CTTRIG =0;
    IDISSEN = 0;



    IRNG0 = 0;  //current source disabled.
    IRNG1 = 0;

}
