#ifndef	_HTC_H_
#warning Header file pic18f65k22.h included directly. Use #include <htc.h> instead.
#endif

 /* header file for the MICROCHIP PIC microcontroller
    18F65K22
 */

#ifndef __PIC18F65K22_H
#define __PIC18F65K22_H


// Config Register: CONFIG1L
// VREG Sleep Enable bit
// Enabled
#define RETEN_ON             0xFFFF 
// Disabled - Controlled by SRETEN bit
#define RETEN_OFF            0xFFFE 
// LF-INTOSC Low-power Enable bit
// LF-INTOSC in High-power mode during Sleep
#define INTOSCSEL_HIGH       0xFFFF 
// LF-INTOSC in Low-power mode during Sleep
#define INTOSCSEL_LOW        0xFFFB 
// SOSC Power Selection and mode Configuration bits
// High Power SOSC circuit selected
#define SOSCSEL_HIGH         0xFFFF 
// Low Power SOSC circuit selected
#define SOSCSEL_LOW          0xFFEF 
// Digital (SCLKI) mode
#define SOSCSEL_DIG          0xFFF7 
// Extended Instruction Set
// Enabled
#define XINST_ON             0xFFFF 
// Disabled
#define XINST_OFF            0xFFBF 


// Config Register: CONFIG1H
// Oscillator
// External RC oscillator
#define FOSC_RCIO            0xF0FF 
// External RC oscillator, CLKOUT function on OSC2
#define FOSC_RC              0xF1FF 
// EC oscillator (Low power, DC - 160 kHz)
#define FOSC_EC1             0xFAFF 
// EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)
#define FOSC_EC1IO           0xFBFF 
// EC oscillator (Medium power, 160 kHz - 4 MHz)
#define FOSC_EC2             0xFCFF 
// EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)
#define FOSC_EC2IO           0xFDFF 
// Internal RC oscillator, CLKOUT function on OSC2
#define FOSC_INTIO1          0xFEFF 
// Internal RC oscillator
#define FOSC_INTIO2          0xFFFF 
// EC oscillator (High power, 16 MHz - 64 MHz)
#define FOSC_EC3             0xF2FF 
// EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)
#define FOSC_EC3IO           0xF3FF 
// HS oscillator (Medium power, 4 MHz - 16 MHz)
#define FOSC_HS1             0xF4FF 
// HS oscillator (High power, 16 MHz - 25 MHz)
#define FOSC_HS2             0xF5FF 
// XT oscillator
#define FOSC_XT              0xF6FF 
// LP oscillator
#define FOSC_LP              0xF7FF 
// PLL x4 Enable bit
// Enabled
#define PLLCFG_ON            0xEFFF 
// Disabled
#define PLLCFG_OFF           0xFFFF 
// Fail-Safe Clock Monitor
// Disabled
#define FCMEN_OFF            0xFFFF 
// Enabled
#define FCMEN_ON             0xBFFF 
// Internal External Oscillator Switch Over Mode
// Disabled
#define IESO_OFF             0xFFFF 
// Enabled
#define IESO_ON              0x7FFF 


// Config Register: CONFIG2L
// Power Up Timer
// Disabled
#define PWRTEN_OFF           0xFFFF 
// Enabled
#define PWRTEN_ON            0xFFFE 
// Brown Out Detect
// Enabled in hardware, SBOREN disabled
#define BOREN_SBORDIS        0xFFFF 
// Enabled while active, disabled in SLEEP, SBOREN disabled
#define BOREN_NOSLP          0xFFFD 
// Controlled with SBOREN bit
#define BOREN_ON             0xFFFB 
// Disabled in hardware, SBOREN disabled
#define BOREN_OFF            0xFFF9 
// Brown-out Reset Voltage bits
// 1.8V
#define BORV_3               0xFFFF 
// 2.0V
#define BORV_2               0xFFF7 
// 2.7V
#define BORV_1               0xFFEF 
// 3.0V
#define BORV_0               0xFFE7 
// BORMV Power level
// ZPBORMV instead of BORMV is selected
#define BORPWR_ZPBORMV       0xFFFF 
// BORMV set to high power level
#define BORPWR_HIGH          0xFFDF 
// BORMV set to medium power level
#define BORPWR_MEDIUM        0xFFBF 
// BORMV set to low power level
#define BORPWR_LOW           0xFF9F 


// Config Register: CONFIG2H
// Watchdog Timer
// WDT enabled in hardware; SWDTEN bit disabled
#define WDTEN_SWDTDIS        0xFFFF 
// WDT controlled by SWDTEN bit setting
#define WDTEN_ON             0xFEFF 
// WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled
#define WDTEN_NOSLP          0xFDFF 
// WDT disabled in hardware; SWDTEN bit disabled
#define WDTEN_OFF            0xFCFF 
// Watchdog Postscaler
// 1:1048576
#define WDTPS_1048576        0xD3FF 
// 1:524288
#define WDTPS_524288         0xCFFF 
// 1:262144
#define WDTPS_262144         0xCBFF 
// 1:131072
#define WDTPS_131072         0xC7FF 
// 1:65536
#define WDTPS_65536          0xC3FF 
// 1:32768
#define WDTPS_32768          0xBFFF 
// 1:16384
#define WDTPS_16384          0xBBFF 
// 1:8192
#define WDTPS_8192           0xB7FF 
// 1:4096
#define WDTPS_4096           0xB3FF 
// 1:2048
#define WDTPS_2048           0xAFFF 
// 1:1024
#define WDTPS_1024           0xABFF 
// 1:512
#define WDTPS_512            0xA7FF 
// 1:256
#define WDTPS_256            0xA3FF 
// 1:128
#define WDTPS_128            0x9FFF 
// 1:64
#define WDTPS_64             0x9BFF 
// 1:32
#define WDTPS_32             0x97FF 
// 1:16
#define WDTPS_16             0x93FF 
// 1:8
#define WDTPS_8              0x8FFF 
// 1:4
#define WDTPS_4              0x8BFF 
// 1:2
#define WDTPS_2              0x87FF 
// 1:1
#define WDTPS_1              0x83FF 


// Config Register: CONFIG3L
// RTCC Clock Select
// RTCC uses SOSC
#define RTCOSC_SOSCREF       0xFFFF 
// RTCC uses INTRC
#define RTCOSC_INTOSCREF     0xFFFE 


// Config Register: CONFIG3H
// CCP2 Mux
// RC1
#define CCP2MX_PORTC         0xFFFF 
// RE7-Microcontroller Mode/RB3-All other modes
#define CCP2MX_PORTBE        0xFEFF 
// MSSP address masking
// 7 Bit address masking mode
#define MSSPMSK_MSK7         0xFFFF 
// 5 bit address masking mode
#define MSSPMSK_MSK5         0xF7FF 
// Master Clear Enable
// MCLR Enabled, RG5 Disabled
#define MCLRE_ON             0xFFFF 
// MCLR Disabled, RG5 Enabled
#define MCLRE_OFF            0x7FFF 


// Config Register: CONFIG4L
// Stack Overflow Reset
// Enabled
#define STVREN_ON            0xFFFF 
// Disabled
#define STVREN_OFF           0xFFFE 
// Boot Block Size
// 2K word Boot Block size
#define BBSIZ_BB2K           0xFFFF 
// 1K word Boot Block size
#define BBSIZ_BB1K           0xFFEF 


// Config Register: CONFIG5L
// Code Protect 00800-01FFF
// Disabled
#define CP0_OFF              0xFFFF 
// Enabled
#define CP0_ON               0xFFFE 
// Code Protect 02000-03FFF
// Disabled
#define CP1_OFF              0xFFFF 
// Enabled
#define CP1_ON               0xFFFD 
// Code Protect 04000-05FFF
// Disabled
#define CP2_OFF              0xFFFF 
// Enabled
#define CP2_ON               0xFFFB 
// Code Protect 06000-07FFF
// Disabled
#define CP3_OFF              0xFFFF 
// Enabled
#define CP3_ON               0xFFF7 


// Config Register: CONFIG5H
// Code Protect Boot
// Disabled
#define CPB_OFF              0xFFFF 
// Enabled
#define CPB_ON               0xBFFF 
// Data EE Read Protect
// Disabled
#define CPD_OFF              0xFFFF 
// Enabled
#define CPD_ON               0x7FFF 


// Config Register: CONFIG6L
// Table Write Protect 00800-017FF
// Disabled
#define WRT0_OFF             0xFFFF 
// Enabled
#define WRT0_ON              0xFFFE 
// Table Write Protect 01800-03FFF
// Disabled
#define WRT1_OFF             0xFFFF 
// Enabled
#define WRT1_ON              0xFFFD 
// Table Write Protect 04000-05FFF
// Disabled
#define WRT2_OFF             0xFFFF 
// Enabled
#define WRT2_ON              0xFFFB 
// Table Write Protect 06000-07FFF
// Disabled
#define WRT3_OFF             0xFFFF 
// Enabled
#define WRT3_ON              0xFFF7 


// Config Register: CONFIG6H
// Config. Write Protect
// Disabled
#define WRTC_OFF             0xFFFF 
// Enabled
#define WRTC_ON              0xDFFF 
// Table Write Protect Boot
// Disabled
#define WRTB_OFF             0xFFFF 
// Enabled
#define WRTB_ON              0xBFFF 
// Data EE Write Protect
// Disabled
#define WRTD_OFF             0xFFFF 
// Enabled
#define WRTD_ON              0x7FFF 


// Config Register: CONFIG7L
// Table Read Protect 00800-017FF
// Disabled
#define EBRT0_OFF            0xFFFF 
// Enabled
#define EBRT0_ON             0xFFFE 
// Table Read Protect 01800-03FFF
// Disabled
#define EBRT1_OFF            0xFFFF 
// Enabled
#define EBRT1_ON             0xFFFD 
// Table Read Protect 04000-05FFF
// Disabled
#define EBRT2_OFF            0xFFFF 
// Enabled
#define EBRT2_ON             0xFFFB 
// Table Read Protect 06000-07FFF
// Disabled
#define EBRT3_OFF            0xFFFF 
// Enabled
#define EBRT3_ON             0xFFF7 


// Config Register: CONFIG7H
// Table Read Protect Boot
// Disabled
#define EBRTB_OFF            0xFFFF 
// Enabled
#define EBRTB_ON             0xBFFF 


//
// Special function register definitions: Bank 0xf
//

// Register: PMD3
static volatile unsigned char           PMD3                @ 0xF16;
// bit and bitfield definitions
static volatile bit CCP4MD              @ ((unsigned)&PMD3*8)+1;
static volatile bit CCP5MD              @ ((unsigned)&PMD3*8)+2;
static volatile bit CCP6MD              @ ((unsigned)&PMD3*8)+3;
static volatile bit CCP7MD              @ ((unsigned)&PMD3*8)+4;
static volatile bit CCP8MD              @ ((unsigned)&PMD3*8)+5;

// Register: PMD2
static volatile unsigned char           PMD2                @ 0xF17;
// bit and bitfield definitions
static volatile bit CMP1MD              @ ((unsigned)&PMD2*8)+0;
static volatile bit CMP2MD              @ ((unsigned)&PMD2*8)+1;
static volatile bit CMP3MD              @ ((unsigned)&PMD2*8)+2;
static volatile bit TMR5MD              @ ((unsigned)&PMD2*8)+3;
static volatile bit TMR6MD              @ ((unsigned)&PMD2*8)+4;
static volatile bit TMR8MD              @ ((unsigned)&PMD2*8)+6;

// Register: PMD1
static volatile unsigned char           PMD1                @ 0xF18;
// bit and bitfield definitions
static volatile bit EMBMD               @ ((unsigned)&PMD1*8)+0;
static volatile bit TMR1MD              @ ((unsigned)&PMD1*8)+1;
static volatile bit TMR2MD              @ ((unsigned)&PMD1*8)+2;
static volatile bit TMR3MD              @ ((unsigned)&PMD1*8)+3;
static volatile bit TMR4MD              @ ((unsigned)&PMD1*8)+4;
static volatile bit RTCCMD              @ ((unsigned)&PMD1*8)+5;
static volatile bit CTMUMD              @ ((unsigned)&PMD1*8)+6;
static volatile bit PSPMD               @ ((unsigned)&PMD1*8)+7;

// Register: PMD0
static volatile unsigned char           PMD0                @ 0xF19;
// bit and bitfield definitions
static volatile bit ADCMD               @ ((unsigned)&PMD0*8)+0;
static volatile bit SSP1MD              @ ((unsigned)&PMD0*8)+1;
static volatile bit SSP2MD              @ ((unsigned)&PMD0*8)+2;
static volatile bit UART1MD             @ ((unsigned)&PMD0*8)+3;
static volatile bit UART2MD             @ ((unsigned)&PMD0*8)+4;
static volatile bit CCP1MD              @ ((unsigned)&PMD0*8)+5;
static volatile bit CCP2MD              @ ((unsigned)&PMD0*8)+6;
static volatile bit CCP3MD              @ ((unsigned)&PMD0*8)+7;

// Register: PSTR3CON
static volatile unsigned char           PSTR3CON            @ 0xF1A;
// bit and bitfield definitions
//static volatile bit STRA               @ ((unsigned)&PSTR3CON*8)+0;
//static volatile bit STRB               @ ((unsigned)&PSTR3CON*8)+1;
//static volatile bit STRC               @ ((unsigned)&PSTR3CON*8)+2;
//static volatile bit STRD               @ ((unsigned)&PSTR3CON*8)+3;
//static volatile bit STRSYNC            @ ((unsigned)&PSTR3CON*8)+4;
//static volatile bit CMPL0              @ ((unsigned)&PSTR3CON*8)+6;
//static volatile bit CMPL1              @ ((unsigned)&PSTR3CON*8)+7;

// Register: PSTR2CON
static volatile unsigned char           PSTR2CON            @ 0xF1B;
// bit and bitfield definitions
//static volatile bit STRA               @ ((unsigned)&PSTR2CON*8)+0;
//static volatile bit STRB               @ ((unsigned)&PSTR2CON*8)+1;
//static volatile bit STRC               @ ((unsigned)&PSTR2CON*8)+2;
//static volatile bit STRD               @ ((unsigned)&PSTR2CON*8)+3;
//static volatile bit STRSYNC            @ ((unsigned)&PSTR2CON*8)+4;
//static volatile bit CMPL0              @ ((unsigned)&PSTR2CON*8)+6;
//static volatile bit CMPL1              @ ((unsigned)&PSTR2CON*8)+7;

// Register: TXREG2
static volatile unsigned char           TXREG2              @ 0xF1C;
// bit and bitfield definitions

// Register: RCREG2
static volatile unsigned char           RCREG2              @ 0xF1D;
// bit and bitfield definitions

// Register: SPBRG2
static volatile unsigned char           SPBRG2              @ 0xF1E;
// bit and bitfield definitions

// Register: SPBRGH2
static volatile unsigned char           SPBRGH2             @ 0xF1F;
// bit and bitfield definitions

// Register: BAUDCON2
static volatile unsigned char           BAUDCON2            @ 0xF20;
// bit and bitfield definitions
//static volatile bit ABDEN              @ ((unsigned)&BAUDCON2*8)+0;
//static volatile bit WUE                @ ((unsigned)&BAUDCON2*8)+1;
//static volatile bit BRG16              @ ((unsigned)&BAUDCON2*8)+3;
//static volatile bit TXCKP              @ ((unsigned)&BAUDCON2*8)+4;
//static volatile bit RXDTP              @ ((unsigned)&BAUDCON2*8)+5;
//static volatile bit RCIDL              @ ((unsigned)&BAUDCON2*8)+6;
//static volatile bit ABDOVF             @ ((unsigned)&BAUDCON2*8)+7;

// Register: TXSTA2
static volatile unsigned char           TXSTA2              @ 0xF21;
// bit and bitfield definitions
//static volatile bit TX9D               @ ((unsigned)&TXSTA2*8)+0;
//static volatile bit TRMT               @ ((unsigned)&TXSTA2*8)+1;
//static volatile bit BRGH               @ ((unsigned)&TXSTA2*8)+2;
//static volatile bit SENDB              @ ((unsigned)&TXSTA2*8)+3;
//static volatile bit SYNC               @ ((unsigned)&TXSTA2*8)+4;
//static volatile bit TXEN               @ ((unsigned)&TXSTA2*8)+5;
//static volatile bit TX9                @ ((unsigned)&TXSTA2*8)+6;
//static volatile bit CSRC               @ ((unsigned)&TXSTA2*8)+7;

// Register: RCSTA2
static volatile unsigned char           RCSTA2              @ 0xF22;
// bit and bitfield definitions
//static volatile bit RX9D               @ ((unsigned)&RCSTA2*8)+0;
//static volatile bit OERR               @ ((unsigned)&RCSTA2*8)+1;
//static volatile bit FERR               @ ((unsigned)&RCSTA2*8)+2;
//static volatile bit ADDEN              @ ((unsigned)&RCSTA2*8)+3;
//static volatile bit CREN               @ ((unsigned)&RCSTA2*8)+4;
//static volatile bit SREN               @ ((unsigned)&RCSTA2*8)+5;
//static volatile bit RX9                @ ((unsigned)&RCSTA2*8)+6;
//static volatile bit SPEN               @ ((unsigned)&RCSTA2*8)+7;

// Register: ANCON2
static volatile unsigned char           ANCON2              @ 0xF23;
// bit and bitfield definitions
static volatile bit ANSEL16             @ ((unsigned)&ANCON2*8)+0;
static volatile bit ANSEL17             @ ((unsigned)&ANCON2*8)+1;
static volatile bit ANSEL18             @ ((unsigned)&ANCON2*8)+2;
static volatile bit ANSEL19             @ ((unsigned)&ANCON2*8)+3;

// Register: ANCON1
static volatile unsigned char           ANCON1              @ 0xF24;
// bit and bitfield definitions
static volatile bit ANSEL8              @ ((unsigned)&ANCON1*8)+0;
static volatile bit ANSEL9              @ ((unsigned)&ANCON1*8)+1;
static volatile bit ANSEL10             @ ((unsigned)&ANCON1*8)+2;
static volatile bit ANSEL11             @ ((unsigned)&ANCON1*8)+3;

// Register: ANCON0
static volatile unsigned char           ANCON0              @ 0xF25;
// bit and bitfield definitions
static volatile bit ANSEL0              @ ((unsigned)&ANCON0*8)+0;
static volatile bit ANSEL1              @ ((unsigned)&ANCON0*8)+1;
static volatile bit ANSEL2              @ ((unsigned)&ANCON0*8)+2;
static volatile bit ANSEL3              @ ((unsigned)&ANCON0*8)+3;
static volatile bit ANSEL4              @ ((unsigned)&ANCON0*8)+4;
static volatile bit ANSEL5              @ ((unsigned)&ANCON0*8)+5;
static volatile bit ANSEL6              @ ((unsigned)&ANCON0*8)+6;
static volatile bit ANSEL7              @ ((unsigned)&ANCON0*8)+7;

// Register: ODCON3
static volatile unsigned char           ODCON3              @ 0xF27;
// bit and bitfield definitions
static volatile bit CTMUDS              @ ((unsigned)&ODCON3*8)+0;
static volatile bit U1OD                @ ((unsigned)&ODCON3*8)+6;
static volatile bit U2OD                @ ((unsigned)&ODCON3*8)+7;

// Register: ODCON2
static volatile unsigned char           ODCON2              @ 0xF28;
// bit and bitfield definitions
static volatile bit CCP3OD              @ ((unsigned)&ODCON2*8)+0;
static volatile bit CCP4OD              @ ((unsigned)&ODCON2*8)+1;
static volatile bit CCP5OD              @ ((unsigned)&ODCON2*8)+2;
static volatile bit CCP6OD              @ ((unsigned)&ODCON2*8)+3;
static volatile bit CCP7OD              @ ((unsigned)&ODCON2*8)+4;
static volatile bit CCP8OD              @ ((unsigned)&ODCON2*8)+5;

// Register: ODCON1
static volatile unsigned char           ODCON1              @ 0xF29;
// bit and bitfield definitions
static volatile bit SPI2OD              @ ((unsigned)&ODCON1*8)+0;
static volatile bit CCP1OD              @ ((unsigned)&ODCON1*8)+5;
static volatile bit CCP2OD              @ ((unsigned)&ODCON1*8)+6;
static volatile bit SPI1OD              @ ((unsigned)&ODCON1*8)+7;

// Register: REFOCON
static volatile unsigned char           REFOCON             @ 0xF2A;
// bit and bitfield definitions
static volatile bit ROSEL               @ ((unsigned)&REFOCON*8)+4;
static volatile bit ROSSLP              @ ((unsigned)&REFOCON*8)+5;
static volatile bit ROON                @ ((unsigned)&REFOCON*8)+7;
static volatile bit RODIV0              @ ((unsigned)&REFOCON*8)+0;
static volatile bit RODIV1              @ ((unsigned)&REFOCON*8)+1;
static volatile bit RODIV2              @ ((unsigned)&REFOCON*8)+2;
static volatile bit RODIV3              @ ((unsigned)&REFOCON*8)+3;

// Register: CCPTMRS2
static volatile unsigned char           CCPTMRS2            @ 0xF2B;
// bit and bitfield definitions
static volatile bit C8TSEL0             @ ((unsigned)&CCPTMRS2*8)+0;
static volatile bit C8TSEL1             @ ((unsigned)&CCPTMRS2*8)+1;

// Register: CCPTMRS1
static volatile unsigned char           CCPTMRS1            @ 0xF2C;
// bit and bitfield definitions
static volatile bit C5TSEL0             @ ((unsigned)&CCPTMRS1*8)+2;
static volatile bit C6TSEL0             @ ((unsigned)&CCPTMRS1*8)+4;
static volatile bit C4TSEL0             @ ((unsigned)&CCPTMRS1*8)+0;
static volatile bit C4TSEL1             @ ((unsigned)&CCPTMRS1*8)+1;
static volatile bit C7TSEL0             @ ((unsigned)&CCPTMRS1*8)+6;
static volatile bit C7TSEL1             @ ((unsigned)&CCPTMRS1*8)+7;

// Register: CCPTMRS0
static volatile unsigned char           CCPTMRS0            @ 0xF2D;
// bit and bitfield definitions
static volatile bit C1TSEL0             @ ((unsigned)&CCPTMRS0*8)+0;
static volatile bit C1TSEL1             @ ((unsigned)&CCPTMRS0*8)+1;
static volatile bit C1TSEL2             @ ((unsigned)&CCPTMRS0*8)+2;
static volatile bit C2TSEL0             @ ((unsigned)&CCPTMRS0*8)+3;
static volatile bit C2TSEL1             @ ((unsigned)&CCPTMRS0*8)+4;
static volatile bit C2TSEL2             @ ((unsigned)&CCPTMRS0*8)+5;
static volatile bit C3TSEL0             @ ((unsigned)&CCPTMRS0*8)+6;
static volatile bit C3TSEL1             @ ((unsigned)&CCPTMRS0*8)+7;

// Register: CM3CON
static volatile unsigned char           CM3CON              @ 0xF2E;
static volatile unsigned char           CM3CON1             @ 0xF2E;
// bit and bitfield definitions
//static volatile bit CREF               @ ((unsigned)&CM3CON*8)+2;
//static volatile bit CPOL               @ ((unsigned)&CM3CON*8)+5;
//static volatile bit COE                @ ((unsigned)&CM3CON*8)+6;
//static volatile bit CON                @ ((unsigned)&CM3CON*8)+7;
//static volatile bit CCH0               @ ((unsigned)&CM3CON*8)+0;
//static volatile bit CCH1               @ ((unsigned)&CM3CON*8)+1;
//static volatile bit EVPOL0             @ ((unsigned)&CM3CON*8)+3;
//static volatile bit EVPOL1             @ ((unsigned)&CM3CON*8)+4;

// Register: CM2CON
static volatile unsigned char           CM2CON              @ 0xF2F;
static volatile unsigned char           CM2CON1             @ 0xF2F;
// bit and bitfield definitions
//static volatile bit CREF               @ ((unsigned)&CM2CON*8)+2;
//static volatile bit CPOL               @ ((unsigned)&CM2CON*8)+5;
//static volatile bit COE                @ ((unsigned)&CM2CON*8)+6;
//static volatile bit CON                @ ((unsigned)&CM2CON*8)+7;
//static volatile bit CCH0               @ ((unsigned)&CM2CON*8)+0;
//static volatile bit CCH1               @ ((unsigned)&CM2CON*8)+1;
//static volatile bit EVPOL0             @ ((unsigned)&CM2CON*8)+3;
//static volatile bit EVPOL1             @ ((unsigned)&CM2CON*8)+4;

// Register: T8CON
static volatile unsigned char           T8CON               @ 0xF36;
// bit and bitfield definitions
static volatile bit TMR8ON              @ ((unsigned)&T8CON*8)+2;
static volatile bit T8CKPS0             @ ((unsigned)&T8CON*8)+0;
static volatile bit T8CKPS1             @ ((unsigned)&T8CON*8)+1;
static volatile bit T8OUTPS0            @ ((unsigned)&T8CON*8)+3;
static volatile bit T8OUTPS1            @ ((unsigned)&T8CON*8)+4;
static volatile bit T8OUTPS2            @ ((unsigned)&T8CON*8)+5;
static volatile bit T8OUTPS3            @ ((unsigned)&T8CON*8)+6;

// Register: PR8
static volatile unsigned char           PR8                 @ 0xF37;
// bit and bitfield definitions

// Register: TMR8
static volatile unsigned char           TMR8                @ 0xF38;
// bit and bitfield definitions

// Register: T6CON
static volatile unsigned char           T6CON               @ 0xF39;
// bit and bitfield definitions
static volatile bit TMR6ON              @ ((unsigned)&T6CON*8)+2;
static volatile bit T6CKPS0             @ ((unsigned)&T6CON*8)+0;
static volatile bit T6CKPS1             @ ((unsigned)&T6CON*8)+1;
static volatile bit T6OUTPS0            @ ((unsigned)&T6CON*8)+3;
static volatile bit T6OUTPS1            @ ((unsigned)&T6CON*8)+4;
static volatile bit T6OUTPS2            @ ((unsigned)&T6CON*8)+5;
static volatile bit T6OUTPS3            @ ((unsigned)&T6CON*8)+6;

// Register: PR6
static volatile unsigned char           PR6                 @ 0xF3A;
// bit and bitfield definitions

// Register: TMR6
static volatile unsigned char           TMR6                @ 0xF3B;
// bit and bitfield definitions

// Register: CCP8CON
static volatile unsigned char           CCP8CON             @ 0xF46;
// bit and bitfield definitions
static volatile bit CCP8M0              @ ((unsigned)&CCP8CON*8)+0;
static volatile bit CCP8M1              @ ((unsigned)&CCP8CON*8)+1;
static volatile bit CCP8M2              @ ((unsigned)&CCP8CON*8)+2;
static volatile bit CCP8M3              @ ((unsigned)&CCP8CON*8)+3;
static volatile bit DC8B0               @ ((unsigned)&CCP8CON*8)+4;
static volatile bit DC8B1               @ ((unsigned)&CCP8CON*8)+5;
static volatile bit CCP8Y               @ ((unsigned)&CCP8CON*8)+4;
static volatile bit CCP8X               @ ((unsigned)&CCP8CON*8)+5;

// Register: CCPR8L
static volatile unsigned char           CCPR8L              @ 0xF47;
// bit and bitfield definitions

// Register: CCPR8H
static volatile unsigned char           CCPR8H              @ 0xF48;
// bit and bitfield definitions

// Register: CCPR8
static volatile unsigned int            CCPR8               @ 0xF47;

// Register: CCP3CON
static volatile unsigned char           CCP3CON             @ 0xF49;
// bit and bitfield definitions
static volatile bit CCP3M0              @ ((unsigned)&CCP3CON*8)+0;
static volatile bit CCP3M1              @ ((unsigned)&CCP3CON*8)+1;
static volatile bit CCP3M2              @ ((unsigned)&CCP3CON*8)+2;
static volatile bit CCP3M3              @ ((unsigned)&CCP3CON*8)+3;
static volatile bit DC3B0               @ ((unsigned)&CCP3CON*8)+4;
static volatile bit DC3B1               @ ((unsigned)&CCP3CON*8)+5;
static volatile bit P3M0                @ ((unsigned)&CCP3CON*8)+6;
static volatile bit P3M1                @ ((unsigned)&CCP3CON*8)+7;

// Register: CCPR3L
static volatile unsigned char           CCPR3L              @ 0xF4A;
// bit and bitfield definitions

// Register: CCPR3H
static volatile unsigned char           CCPR3H              @ 0xF4B;
// bit and bitfield definitions

// Register: CCPR3
static volatile unsigned int            CCPR3               @ 0xF4A;

// Register: ECCP3DEL
static volatile unsigned char           ECCP3DEL            @ 0xF4C;
// bit and bitfield definitions
static volatile bit P3RSEN              @ ((unsigned)&ECCP3DEL*8)+7;
static volatile bit P3DC0               @ ((unsigned)&ECCP3DEL*8)+0;
static volatile bit P3DC1               @ ((unsigned)&ECCP3DEL*8)+1;
static volatile bit P3DC2               @ ((unsigned)&ECCP3DEL*8)+2;
static volatile bit P3DC3               @ ((unsigned)&ECCP3DEL*8)+3;
static volatile bit P3DC4               @ ((unsigned)&ECCP3DEL*8)+4;
static volatile bit P3DC5               @ ((unsigned)&ECCP3DEL*8)+5;
static volatile bit P3DC6               @ ((unsigned)&ECCP3DEL*8)+6;

// Register: ECCP3AS
static volatile unsigned char           ECCP3AS             @ 0xF4D;
// bit and bitfield definitions
static volatile bit ECCP3ASE            @ ((unsigned)&ECCP3AS*8)+7;
static volatile bit PSS3BD0             @ ((unsigned)&ECCP3AS*8)+0;
static volatile bit PSS3BD1             @ ((unsigned)&ECCP3AS*8)+1;
static volatile bit PSS3AC0             @ ((unsigned)&ECCP3AS*8)+2;
static volatile bit PSS3AC1             @ ((unsigned)&ECCP3AS*8)+3;
static volatile bit ECCP3AS0            @ ((unsigned)&ECCP3AS*8)+4;
static volatile bit ECCP3AS1            @ ((unsigned)&ECCP3AS*8)+5;
static volatile bit ECCP3AS2            @ ((unsigned)&ECCP3AS*8)+6;

// Register: CCP2CON
static volatile unsigned char           CCP2CON             @ 0xF4E;
static volatile unsigned char           ECCP2CON            @ 0xF4E;
// bit and bitfield definitions
static volatile bit CCP2M0              @ ((unsigned)&CCP2CON*8)+0;
static volatile bit CCP2M1              @ ((unsigned)&CCP2CON*8)+1;
static volatile bit CCP2M2              @ ((unsigned)&CCP2CON*8)+2;
static volatile bit CCP2M3              @ ((unsigned)&CCP2CON*8)+3;
static volatile bit DC2B0               @ ((unsigned)&CCP2CON*8)+4;
static volatile bit DC2B1               @ ((unsigned)&CCP2CON*8)+5;
static volatile bit P2M0                @ ((unsigned)&CCP2CON*8)+6;
static volatile bit P2M1                @ ((unsigned)&CCP2CON*8)+7;
static volatile bit CCP2Y               @ ((unsigned)&CCP2CON*8)+4;
static volatile bit CCP2X               @ ((unsigned)&CCP2CON*8)+5;

// Register: CCPR2L
static volatile unsigned char           CCPR2L              @ 0xF4F;
// bit and bitfield definitions

// Register: CCPR2H
static volatile unsigned char           CCPR2H              @ 0xF50;
// bit and bitfield definitions

// Register: CCPR2
static volatile unsigned int            CCPR2               @ 0xF4F;

// Register: ECCP2DEL
static volatile unsigned char           ECCP2DEL            @ 0xF51;
static volatile unsigned char           PWM2CON             @ 0xF51;
// bit and bitfield definitions
static volatile bit P2RSEN              @ ((unsigned)&ECCP2DEL*8)+7;
static volatile bit P2DC0               @ ((unsigned)&ECCP2DEL*8)+0;
static volatile bit P2DC1               @ ((unsigned)&ECCP2DEL*8)+1;
static volatile bit P2DC2               @ ((unsigned)&ECCP2DEL*8)+2;
static volatile bit P2DC3               @ ((unsigned)&ECCP2DEL*8)+3;
static volatile bit P2DC4               @ ((unsigned)&ECCP2DEL*8)+4;
static volatile bit P2DC5               @ ((unsigned)&ECCP2DEL*8)+5;
static volatile bit P2DC6               @ ((unsigned)&ECCP2DEL*8)+6;

// Register: ECCP2AS
static volatile unsigned char           ECCP2AS             @ 0xF52;
// bit and bitfield definitions
static volatile bit ECCP2ASE            @ ((unsigned)&ECCP2AS*8)+7;
static volatile bit PSS2BD0             @ ((unsigned)&ECCP2AS*8)+0;
static volatile bit PSS2BD1             @ ((unsigned)&ECCP2AS*8)+1;
static volatile bit PSS2AC0             @ ((unsigned)&ECCP2AS*8)+2;
static volatile bit PSS2AC1             @ ((unsigned)&ECCP2AS*8)+3;
static volatile bit ECCP2AS0            @ ((unsigned)&ECCP2AS*8)+4;
static volatile bit ECCP2AS1            @ ((unsigned)&ECCP2AS*8)+5;
static volatile bit ECCP2AS2            @ ((unsigned)&ECCP2AS*8)+6;

// Register: PADCFG1
static volatile unsigned char           PADCFG1             @ 0xF53;
// bit and bitfield definitions
static volatile bit REPU                @ ((unsigned)&PADCFG1*8)+6;
static volatile bit RDPU                @ ((unsigned)&PADCFG1*8)+7;
static volatile bit RTSECSEL0           @ ((unsigned)&PADCFG1*8)+1;
static volatile bit RTSECSEL1           @ ((unsigned)&PADCFG1*8)+2;

// Register: CM1CON
static volatile unsigned char           CM1CON              @ 0xF54;
static volatile unsigned char           CM1CON1             @ 0xF54;
// bit and bitfield definitions
//static volatile bit CREF               @ ((unsigned)&CM1CON*8)+2;
//static volatile bit CPOL               @ ((unsigned)&CM1CON*8)+5;
//static volatile bit COE                @ ((unsigned)&CM1CON*8)+6;
//static volatile bit CON                @ ((unsigned)&CM1CON*8)+7;
//static volatile bit CCH0               @ ((unsigned)&CM1CON*8)+0;
//static volatile bit CCH1               @ ((unsigned)&CM1CON*8)+1;
//static volatile bit EVPOL0             @ ((unsigned)&CM1CON*8)+3;
//static volatile bit EVPOL1             @ ((unsigned)&CM1CON*8)+4;

// Register: CTMUICON
static volatile unsigned char           CTMUICON            @ 0xF55;
// bit and bitfield definitions
static volatile bit IRNG0               @ ((unsigned)&CTMUICON*8)+0;
static volatile bit IRNG1               @ ((unsigned)&CTMUICON*8)+1;
static volatile bit ITRIM0              @ ((unsigned)&CTMUICON*8)+2;
static volatile bit ITRIM1              @ ((unsigned)&CTMUICON*8)+3;
static volatile bit ITRIM2              @ ((unsigned)&CTMUICON*8)+4;
static volatile bit ITRIM3              @ ((unsigned)&CTMUICON*8)+5;
static volatile bit ITRIM4              @ ((unsigned)&CTMUICON*8)+6;
static volatile bit ITRIM5              @ ((unsigned)&CTMUICON*8)+7;

// Register: CTMUCONL
static volatile unsigned char           CTMUCONL            @ 0xF56;
// bit and bitfield definitions
static volatile bit EDG1STAT            @ ((unsigned)&CTMUCONL*8)+0;
static volatile bit EDG2STAT            @ ((unsigned)&CTMUCONL*8)+1;
static volatile bit EDG1POL             @ ((unsigned)&CTMUCONL*8)+4;
static volatile bit EDG2POL             @ ((unsigned)&CTMUCONL*8)+7;
static volatile bit EDG1SEL0            @ ((unsigned)&CTMUCONL*8)+2;
static volatile bit EDG1SEL1            @ ((unsigned)&CTMUCONL*8)+3;
static volatile bit EDG2SEL0            @ ((unsigned)&CTMUCONL*8)+5;
static volatile bit EDG2SEL1            @ ((unsigned)&CTMUCONL*8)+6;

// Register: CTMUCONH
static volatile unsigned char           CTMUCONH            @ 0xF57;
// bit and bitfield definitions
static volatile bit CTTRIG              @ ((unsigned)&CTMUCONH*8)+0;
static volatile bit IDISSEN             @ ((unsigned)&CTMUCONH*8)+1;
static volatile bit EDGSEQEN            @ ((unsigned)&CTMUCONH*8)+2;
static volatile bit EDGEN               @ ((unsigned)&CTMUCONH*8)+3;
static volatile bit TGEN                @ ((unsigned)&CTMUCONH*8)+4;
static volatile bit CTMUSIDL            @ ((unsigned)&CTMUCONH*8)+5;
static volatile bit CTMUEN              @ ((unsigned)&CTMUCONH*8)+7;

// Register: ALRMVALL
static volatile unsigned char           ALRMVALL            @ 0xF58;
// bit and bitfield definitions

// Register: ALRMVALH
static volatile unsigned char           ALRMVALH            @ 0xF59;
// bit and bitfield definitions

// Register: ALRMVAL
static volatile unsigned int            ALRMVAL             @ 0xF58;

// Register: ALRMRPT
static volatile unsigned char           ALRMRPT             @ 0xF5A;
// bit and bitfield definitions
static volatile bit ARPT0               @ ((unsigned)&ALRMRPT*8)+0;
static volatile bit ARPT1               @ ((unsigned)&ALRMRPT*8)+1;
static volatile bit ARPT2               @ ((unsigned)&ALRMRPT*8)+2;
static volatile bit ARPT3               @ ((unsigned)&ALRMRPT*8)+3;
static volatile bit ARPT4               @ ((unsigned)&ALRMRPT*8)+4;
static volatile bit ARPT5               @ ((unsigned)&ALRMRPT*8)+5;
static volatile bit ARPT6               @ ((unsigned)&ALRMRPT*8)+6;
static volatile bit ARPT7               @ ((unsigned)&ALRMRPT*8)+7;

// Register: ALRMCFG
static volatile unsigned char           ALRMCFG             @ 0xF5B;
// bit and bitfield definitions
static volatile bit CHIME               @ ((unsigned)&ALRMCFG*8)+6;
static volatile bit ALRMEN              @ ((unsigned)&ALRMCFG*8)+7;
static volatile bit ALRMPTR0            @ ((unsigned)&ALRMCFG*8)+0;
static volatile bit ALRMPTR1            @ ((unsigned)&ALRMCFG*8)+1;
static volatile bit AMASK0              @ ((unsigned)&ALRMCFG*8)+2;
static volatile bit AMASK1              @ ((unsigned)&ALRMCFG*8)+3;
static volatile bit AMASK2              @ ((unsigned)&ALRMCFG*8)+4;
static volatile bit AMASK3              @ ((unsigned)&ALRMCFG*8)+5;

// Register: RTCVALL
static volatile unsigned char           RTCVALL             @ 0xF5C;
// bit and bitfield definitions

// Register: RTCVALH
static volatile unsigned char           RTCVALH             @ 0xF5D;
// bit and bitfield definitions

// Register: RTCVAL
static volatile unsigned int            RTCVAL              @ 0xF5C;

// Register: RTCCAL
static volatile unsigned char           RTCCAL              @ 0xF5E;
// bit and bitfield definitions
static volatile bit CAL0                @ ((unsigned)&RTCCAL*8)+0;
static volatile bit CAL1                @ ((unsigned)&RTCCAL*8)+1;
static volatile bit CAL2                @ ((unsigned)&RTCCAL*8)+2;
static volatile bit CAL3                @ ((unsigned)&RTCCAL*8)+3;
static volatile bit CAL4                @ ((unsigned)&RTCCAL*8)+4;
static volatile bit CAL5                @ ((unsigned)&RTCCAL*8)+5;
static volatile bit CAL6                @ ((unsigned)&RTCCAL*8)+6;
static volatile bit CAL7                @ ((unsigned)&RTCCAL*8)+7;

// Register: RTCCFG
static volatile unsigned char           RTCCFG              @ 0xF5F;
// bit and bitfield definitions
static volatile bit RTCOE               @ ((unsigned)&RTCCFG*8)+2;
static volatile bit HALFSEC             @ ((unsigned)&RTCCFG*8)+3;
static volatile bit RTCSYNC             @ ((unsigned)&RTCCFG*8)+4;
static volatile bit RTCWREN             @ ((unsigned)&RTCCFG*8)+5;
static volatile bit RTCEN               @ ((unsigned)&RTCCFG*8)+7;
static volatile bit RTCPTR0             @ ((unsigned)&RTCCFG*8)+0;
static volatile bit RTCPTR1             @ ((unsigned)&RTCCFG*8)+1;

//
// Special function register definitions: Bank 0xf
//

// Register: PIE6
static volatile unsigned char           PIE6                @ 0xF60;
// bit and bitfield definitions
static volatile bit CMP1IE              @ ((unsigned)&PIE6*8)+0;
static volatile bit CMP2IE              @ ((unsigned)&PIE6*8)+1;
static volatile bit CMP3IE              @ ((unsigned)&PIE6*8)+2;
static volatile bit EEIE                @ ((unsigned)&PIE6*8)+4;

// Register: EEDATA
static volatile unsigned char           EEDATA              @ 0xF61;
// bit and bitfield definitions

// Register: EEADR
static volatile unsigned char           EEADR               @ 0xF62;
// bit and bitfield definitions

// Register: EEADRH
static volatile unsigned char           EEADRH              @ 0xF63;
// bit and bitfield definitions

// Register: OSCCON2
static volatile unsigned char           OSCCON2             @ 0xF64;
// bit and bitfield definitions
static volatile bit MFIOSEL             @ ((unsigned)&OSCCON2*8)+0;
static volatile bit MFIOFS              @ ((unsigned)&OSCCON2*8)+1;
static volatile bit SOSCGO              @ ((unsigned)&OSCCON2*8)+3;
static volatile bit SOSCRUN             @ ((unsigned)&OSCCON2*8)+6;

// Register: BAUDCON1
static volatile unsigned char           BAUDCON1            @ 0xF65;
static volatile unsigned char           BAUDCTL             @ 0xF65;
static volatile unsigned char           BAUDCON             @ 0xF65;
// bit and bitfield definitions
//static volatile bit ABDEN              @ ((unsigned)&BAUDCON1*8)+0;
//static volatile bit WUE                @ ((unsigned)&BAUDCON1*8)+1;
//static volatile bit BRG16              @ ((unsigned)&BAUDCON1*8)+3;
//static volatile bit TXCKP              @ ((unsigned)&BAUDCON1*8)+4;
//static volatile bit RXDTP              @ ((unsigned)&BAUDCON1*8)+5;
//static volatile bit RCIDL              @ ((unsigned)&BAUDCON1*8)+6;
//static volatile bit ABDOVF             @ ((unsigned)&BAUDCON1*8)+7;

// Register: SSP2CON2
static volatile unsigned char           SSP2CON2            @ 0xF66;
// bit and bitfield definitions
//static volatile bit SEN                @ ((unsigned)&SSP2CON2*8)+0;
//static volatile bit RSEN               @ ((unsigned)&SSP2CON2*8)+1;
//static volatile bit PEN                @ ((unsigned)&SSP2CON2*8)+2;
//static volatile bit RCEN               @ ((unsigned)&SSP2CON2*8)+3;
//static volatile bit ACKEN              @ ((unsigned)&SSP2CON2*8)+4;
//static volatile bit ACKDT              @ ((unsigned)&SSP2CON2*8)+5;
//static volatile bit ACKSTAT            @ ((unsigned)&SSP2CON2*8)+6;
//static volatile bit GCEN               @ ((unsigned)&SSP2CON2*8)+7;
//static volatile bit ADMSK1             @ ((unsigned)&SSP2CON2*8)+1;
//static volatile bit ADMSK2             @ ((unsigned)&SSP2CON2*8)+2;
//static volatile bit ADMSK3             @ ((unsigned)&SSP2CON2*8)+3;
//static volatile bit ADMSK4             @ ((unsigned)&SSP2CON2*8)+4;
//static volatile bit ADMSK5             @ ((unsigned)&SSP2CON2*8)+5;

// Register: SSP2CON1
static volatile unsigned char           SSP2CON1            @ 0xF67;
// bit and bitfield definitions
//static volatile bit CKP                @ ((unsigned)&SSP2CON1*8)+4;
//static volatile bit SSPEN              @ ((unsigned)&SSP2CON1*8)+5;
//static volatile bit SSPOV              @ ((unsigned)&SSP2CON1*8)+6;
//static volatile bit WCOL               @ ((unsigned)&SSP2CON1*8)+7;
//static volatile bit SSPM0              @ ((unsigned)&SSP2CON1*8)+0;
//static volatile bit SSPM1              @ ((unsigned)&SSP2CON1*8)+1;
//static volatile bit SSPM2              @ ((unsigned)&SSP2CON1*8)+2;
//static volatile bit SSPM3              @ ((unsigned)&SSP2CON1*8)+3;

// Register: SSP2STAT
static volatile unsigned char           SSP2STAT            @ 0xF68;
// bit and bitfield definitions
//static volatile bit BF                 @ ((unsigned)&SSP2STAT*8)+0;
//static volatile bit UA                 @ ((unsigned)&SSP2STAT*8)+1;
//static volatile bit R_nW               @ ((unsigned)&SSP2STAT*8)+2;
//static volatile bit S                  @ ((unsigned)&SSP2STAT*8)+3;
//static volatile bit P                  @ ((unsigned)&SSP2STAT*8)+4;
//static volatile bit D_nA               @ ((unsigned)&SSP2STAT*8)+5;
//static volatile bit CKE                @ ((unsigned)&SSP2STAT*8)+6;
//static volatile bit SMP                @ ((unsigned)&SSP2STAT*8)+7;
//static volatile bit R                  @ ((unsigned)&SSP2STAT*8)+2;
//static volatile bit D                  @ ((unsigned)&SSP2STAT*8)+5;
////static volatile bit R                  @ ((unsigned)&SSP2STAT*8)+2;
////static volatile bit D                  @ ((unsigned)&SSP2STAT*8)+5;
//static volatile bit R_W                @ ((unsigned)&SSP2STAT*8)+2;
//static volatile bit D_A                @ ((unsigned)&SSP2STAT*8)+5;
//static volatile bit nW                 @ ((unsigned)&SSP2STAT*8)+2;
//static volatile bit nA                 @ ((unsigned)&SSP2STAT*8)+5;
//static volatile bit nWRITE             @ ((unsigned)&SSP2STAT*8)+2;
//static volatile bit nADDRESS           @ ((unsigned)&SSP2STAT*8)+5;
//static volatile bit READ_WRITE         @ ((unsigned)&SSP2STAT*8)+2;
//static volatile bit DATA_ADDRESS       @ ((unsigned)&SSP2STAT*8)+5;
//static volatile bit I2C_READ           @ ((unsigned)&SSP2STAT*8)+2;
//static volatile bit I2C_START          @ ((unsigned)&SSP2STAT*8)+3;
//static volatile bit I2C_STOP           @ ((unsigned)&SSP2STAT*8)+4;
//static volatile bit I2C_DAT            @ ((unsigned)&SSP2STAT*8)+5;

// Register: SSP2ADD
static volatile unsigned char           SSP2ADD             @ 0xF69;
// bit and bitfield definitions

// Register: SSP2MSK
static volatile unsigned char           SSP2MSK             @ 0xF69;	// shared address with SSP2ADD
// bit and bitfield definitions
//static volatile bit MSK0               @ ((unsigned)&SSP2MSK*8)+0;
//static volatile bit MSK1               @ ((unsigned)&SSP2MSK*8)+1;
//static volatile bit MSK2               @ ((unsigned)&SSP2MSK*8)+2;
//static volatile bit MSK3               @ ((unsigned)&SSP2MSK*8)+3;
//static volatile bit MSK4               @ ((unsigned)&SSP2MSK*8)+4;
//static volatile bit MSK5               @ ((unsigned)&SSP2MSK*8)+5;
//static volatile bit MSK6               @ ((unsigned)&SSP2MSK*8)+6;
//static volatile bit MSK7               @ ((unsigned)&SSP2MSK*8)+7;

// Register: SSP2BUF
static volatile unsigned char           SSP2BUF             @ 0xF6A;
// bit and bitfield definitions

// Register: T4CON
static volatile unsigned char           T4CON               @ 0xF6B;
// bit and bitfield definitions
static volatile bit TMR4ON              @ ((unsigned)&T4CON*8)+2;
static volatile bit T4CKPS0             @ ((unsigned)&T4CON*8)+0;
static volatile bit T4CKPS1             @ ((unsigned)&T4CON*8)+1;
static volatile bit T4OUTPS0            @ ((unsigned)&T4CON*8)+3;
static volatile bit T4OUTPS1            @ ((unsigned)&T4CON*8)+4;
static volatile bit T4OUTPS2            @ ((unsigned)&T4CON*8)+5;
static volatile bit T4OUTPS3            @ ((unsigned)&T4CON*8)+6;

// Register: PR4
static volatile unsigned char           PR4                 @ 0xF6C;
// bit and bitfield definitions

// Register: TMR4
static volatile unsigned char           TMR4                @ 0xF6D;
// bit and bitfield definitions

// Register: CCP7CON
static volatile unsigned char           CCP7CON             @ 0xF6E;
// bit and bitfield definitions
static volatile bit CCP7M0              @ ((unsigned)&CCP7CON*8)+0;
static volatile bit CCP7M1              @ ((unsigned)&CCP7CON*8)+1;
static volatile bit CCP7M2              @ ((unsigned)&CCP7CON*8)+2;
static volatile bit CCP7M3              @ ((unsigned)&CCP7CON*8)+3;
static volatile bit DC7B0               @ ((unsigned)&CCP7CON*8)+4;
static volatile bit DC7B1               @ ((unsigned)&CCP7CON*8)+5;
static volatile bit CCP7Y               @ ((unsigned)&CCP7CON*8)+4;
static volatile bit CCP7X               @ ((unsigned)&CCP7CON*8)+5;

// Register: CCPR7L
static volatile unsigned char           CCPR7L              @ 0xF6F;
// bit and bitfield definitions

// Register: CCPR7H
static volatile unsigned char           CCPR7H              @ 0xF70;
// bit and bitfield definitions

// Register: CCPR7
static volatile unsigned int            CCPR7               @ 0xF6F;

// Register: CCP6CON
static volatile unsigned char           CCP6CON             @ 0xF71;
// bit and bitfield definitions
static volatile bit CCP6M0              @ ((unsigned)&CCP6CON*8)+0;
static volatile bit CCP6M1              @ ((unsigned)&CCP6CON*8)+1;
static volatile bit CCP6M2              @ ((unsigned)&CCP6CON*8)+2;
static volatile bit CCP6M3              @ ((unsigned)&CCP6CON*8)+3;
static volatile bit DC6B0               @ ((unsigned)&CCP6CON*8)+4;
static volatile bit DC6B1               @ ((unsigned)&CCP6CON*8)+5;
static volatile bit CCP6Y               @ ((unsigned)&CCP6CON*8)+4;
static volatile bit CCP6X               @ ((unsigned)&CCP6CON*8)+5;

// Register: CCPR6L
static volatile unsigned char           CCPR6L              @ 0xF72;
// bit and bitfield definitions

// Register: CCPR6H
static volatile unsigned char           CCPR6H              @ 0xF73;
// bit and bitfield definitions

// Register: CCPR6
static volatile unsigned int            CCPR6               @ 0xF72;

// Register: CCP5CON
static volatile unsigned char           CCP5CON             @ 0xF74;
// bit and bitfield definitions
static volatile bit CCP5M0              @ ((unsigned)&CCP5CON*8)+0;
static volatile bit CCP5M1              @ ((unsigned)&CCP5CON*8)+1;
static volatile bit CCP5M2              @ ((unsigned)&CCP5CON*8)+2;
static volatile bit CCP5M3              @ ((unsigned)&CCP5CON*8)+3;
static volatile bit DC5B0               @ ((unsigned)&CCP5CON*8)+4;
static volatile bit DC5B1               @ ((unsigned)&CCP5CON*8)+5;
static volatile bit CCP5Y               @ ((unsigned)&CCP5CON*8)+4;
static volatile bit CCP5X               @ ((unsigned)&CCP5CON*8)+5;

// Register: CCPR5L
static volatile unsigned char           CCPR5L              @ 0xF75;
// bit and bitfield definitions

// Register: CCPR5H
static volatile unsigned char           CCPR5H              @ 0xF76;
// bit and bitfield definitions

// Register: CCPR5
static volatile unsigned int            CCPR5               @ 0xF75;

// Register: CCP4CON
static volatile unsigned char           CCP4CON             @ 0xF77;
// bit and bitfield definitions
static volatile bit CCP4M0              @ ((unsigned)&CCP4CON*8)+0;
static volatile bit CCP4M1              @ ((unsigned)&CCP4CON*8)+1;
static volatile bit CCP4M2              @ ((unsigned)&CCP4CON*8)+2;
static volatile bit CCP4M3              @ ((unsigned)&CCP4CON*8)+3;
static volatile bit DC4B0               @ ((unsigned)&CCP4CON*8)+4;
static volatile bit DC4B1               @ ((unsigned)&CCP4CON*8)+5;
static volatile bit CCP4Y               @ ((unsigned)&CCP4CON*8)+4;
static volatile bit CCP4X               @ ((unsigned)&CCP4CON*8)+5;

// Register: CCPR4L
static volatile unsigned char           CCPR4L              @ 0xF78;
// bit and bitfield definitions

// Register: CCPR4H
static volatile unsigned char           CCPR4H              @ 0xF79;
// bit and bitfield definitions

// Register: CCPR4
static volatile unsigned int            CCPR4               @ 0xF78;

// Register: T5GCON
static volatile unsigned char           T5GCON              @ 0xF7A;
// bit and bitfield definitions
static volatile bit T5GVAL              @ ((unsigned)&T5GCON*8)+2;
static volatile bit T5GGO_nT5DONE       @ ((unsigned)&T5GCON*8)+3;
static volatile bit T5GSPM              @ ((unsigned)&T5GCON*8)+4;
static volatile bit T5GTM               @ ((unsigned)&T5GCON*8)+5;
static volatile bit T5GPOL              @ ((unsigned)&T5GCON*8)+6;
static volatile bit TMR5GE              @ ((unsigned)&T5GCON*8)+7;
static volatile bit T5GSS0              @ ((unsigned)&T5GCON*8)+0;
static volatile bit T5GSS1              @ ((unsigned)&T5GCON*8)+1;
static volatile bit T5GGO               @ ((unsigned)&T5GCON*8)+3;
static volatile bit nT5DONE             @ ((unsigned)&T5GCON*8)+3;

// Register: T5CON
static volatile unsigned char           T5CON               @ 0xF7B;
// bit and bitfield definitions
static volatile bit TMR5ON              @ ((unsigned)&T5CON*8)+0;
//static volatile bit RD16               @ ((unsigned)&T5CON*8)+1;
static volatile bit nT5SYNC             @ ((unsigned)&T5CON*8)+2;
//static volatile bit SOSCEN             @ ((unsigned)&T5CON*8)+3;
static volatile bit T5CKPS0             @ ((unsigned)&T5CON*8)+4;
static volatile bit T5CKPS1             @ ((unsigned)&T5CON*8)+5;
static volatile bit TMR5CS0             @ ((unsigned)&T5CON*8)+6;
static volatile bit TMR5CS1             @ ((unsigned)&T5CON*8)+7;

// Register: TMR5L
static volatile unsigned char           TMR5L               @ 0xF7C;
// bit and bitfield definitions

// Register: TMR5H
static volatile unsigned char           TMR5H               @ 0xF7D;
// bit and bitfield definitions

// Register: TMR5
static volatile unsigned int            TMR5                @ 0xF7C;

// Register: EECON2
static volatile unsigned char           EECON2              @ 0xF7E;
// bit and bitfield definitions

// Register: EECON1
static volatile unsigned char           EECON1              @ 0xF7F;
// bit and bitfield definitions
static volatile bit RD                  @ ((unsigned)&EECON1*8)+0;
static volatile bit WR                  @ ((unsigned)&EECON1*8)+1;
static volatile bit WREN                @ ((unsigned)&EECON1*8)+2;
static volatile bit WRERR               @ ((unsigned)&EECON1*8)+3;
static volatile bit FREE                @ ((unsigned)&EECON1*8)+4;
static volatile bit CFGS                @ ((unsigned)&EECON1*8)+6;
static volatile bit EEPGD               @ ((unsigned)&EECON1*8)+7;

// Register: PORTA
static volatile unsigned char           PORTA               @ 0xF80;
// bit and bitfield definitions
static volatile bit RA0                 @ ((unsigned)&PORTA*8)+0;
static volatile bit RA1                 @ ((unsigned)&PORTA*8)+1;
static volatile bit RA2                 @ ((unsigned)&PORTA*8)+2;
static volatile bit RA3                 @ ((unsigned)&PORTA*8)+3;
static volatile bit RA4                 @ ((unsigned)&PORTA*8)+4;
static volatile bit RA5                 @ ((unsigned)&PORTA*8)+5;
static volatile bit RA6                 @ ((unsigned)&PORTA*8)+6;
static volatile bit RA7                 @ ((unsigned)&PORTA*8)+7;
static volatile bit AN0                 @ ((unsigned)&PORTA*8)+0;
static volatile bit AN1                 @ ((unsigned)&PORTA*8)+1;
static volatile bit AN2                 @ ((unsigned)&PORTA*8)+2;
static volatile bit AN3                 @ ((unsigned)&PORTA*8)+3;
static volatile bit AN4                 @ ((unsigned)&PORTA*8)+5;
static volatile bit OSC2                @ ((unsigned)&PORTA*8)+6;
static volatile bit OSC1                @ ((unsigned)&PORTA*8)+7;
static volatile bit ULPWU               @ ((unsigned)&PORTA*8)+0;
static volatile bit VREF_MINUS          @ ((unsigned)&PORTA*8)+2;
static volatile bit VREF_PLUS           @ ((unsigned)&PORTA*8)+3;
static volatile bit T0CKI               @ ((unsigned)&PORTA*8)+4;
static volatile bit T1CKI               @ ((unsigned)&PORTA*8)+5;
static volatile bit CLKO                @ ((unsigned)&PORTA*8)+6;
static volatile bit CLKI                @ ((unsigned)&PORTA*8)+7;
static volatile bit T3G                 @ ((unsigned)&PORTA*8)+5;
static volatile bit HLVDIN              @ ((unsigned)&PORTA*8)+5;

// Register: PORTB
static volatile unsigned char           PORTB               @ 0xF81;
// bit and bitfield definitions
static volatile bit RB0                 @ ((unsigned)&PORTB*8)+0;
static volatile bit RB1                 @ ((unsigned)&PORTB*8)+1;
static volatile bit RB2                 @ ((unsigned)&PORTB*8)+2;
static volatile bit RB3                 @ ((unsigned)&PORTB*8)+3;
static volatile bit RB4                 @ ((unsigned)&PORTB*8)+4;
static volatile bit RB5                 @ ((unsigned)&PORTB*8)+5;
static volatile bit RB6                 @ ((unsigned)&PORTB*8)+6;
static volatile bit RB7                 @ ((unsigned)&PORTB*8)+7;
static volatile bit INT0                @ ((unsigned)&PORTB*8)+0;
static volatile bit INT1                @ ((unsigned)&PORTB*8)+1;
static volatile bit INT2                @ ((unsigned)&PORTB*8)+2;
static volatile bit INT3                @ ((unsigned)&PORTB*8)+3;
static volatile bit KBI0                @ ((unsigned)&PORTB*8)+4;
static volatile bit KBI1                @ ((unsigned)&PORTB*8)+5;
static volatile bit KBI2                @ ((unsigned)&PORTB*8)+6;
static volatile bit KBI3                @ ((unsigned)&PORTB*8)+7;
static volatile bit FLT0                @ ((unsigned)&PORTB*8)+0;
static volatile bit CTED1               @ ((unsigned)&PORTB*8)+2;
static volatile bit CTED2               @ ((unsigned)&PORTB*8)+3;
static volatile bit T3CKI               @ ((unsigned)&PORTB*8)+5;
static volatile bit CCP2_P2A            @ ((unsigned)&PORTB*8)+3;
static volatile bit T1G                 @ ((unsigned)&PORTB*8)+5;
static volatile bit PGM                 @ ((unsigned)&PORTB*8)+5;
static volatile bit PGC                 @ ((unsigned)&PORTB*8)+6;
static volatile bit PGD                 @ ((unsigned)&PORTB*8)+7;

// Register: PORTC
static volatile unsigned char           PORTC               @ 0xF82;
// bit and bitfield definitions
static volatile bit RC0                 @ ((unsigned)&PORTC*8)+0;
static volatile bit RC1                 @ ((unsigned)&PORTC*8)+1;
static volatile bit RC2                 @ ((unsigned)&PORTC*8)+2;
static volatile bit RC3                 @ ((unsigned)&PORTC*8)+3;
static volatile bit RC4                 @ ((unsigned)&PORTC*8)+4;
static volatile bit RC5                 @ ((unsigned)&PORTC*8)+5;
static volatile bit RC6                 @ ((unsigned)&PORTC*8)+6;
static volatile bit RC7                 @ ((unsigned)&PORTC*8)+7;
static volatile bit SOSCO               @ ((unsigned)&PORTC*8)+0;
static volatile bit SOSCI               @ ((unsigned)&PORTC*8)+1;
static volatile bit SCK1                @ ((unsigned)&PORTC*8)+3;
static volatile bit SDI1                @ ((unsigned)&PORTC*8)+4;
static volatile bit SDO1                @ ((unsigned)&PORTC*8)+5;
static volatile bit TX1                 @ ((unsigned)&PORTC*8)+6;
static volatile bit RX1                 @ ((unsigned)&PORTC*8)+7;
static volatile bit SCKLI               @ ((unsigned)&PORTC*8)+0;
//static volatile bit CCP2               @ ((unsigned)&PORTC*8)+1;
static volatile bit CCP1                @ ((unsigned)&PORTC*8)+2;
static volatile bit SCL1                @ ((unsigned)&PORTC*8)+3;
static volatile bit SDA1                @ ((unsigned)&PORTC*8)+4;
static volatile bit CK1                 @ ((unsigned)&PORTC*8)+6;
static volatile bit DT1                 @ ((unsigned)&PORTC*8)+7;
//static volatile bit P2A                @ ((unsigned)&PORTC*8)+1;
static volatile bit P1A                 @ ((unsigned)&PORTC*8)+2;

// Register: PORTD
static volatile unsigned char           PORTD               @ 0xF83;
// bit and bitfield definitions
static volatile bit RD0                 @ ((unsigned)&PORTD*8)+0;
static volatile bit RD1                 @ ((unsigned)&PORTD*8)+1;
static volatile bit RD2                 @ ((unsigned)&PORTD*8)+2;
static volatile bit RD3                 @ ((unsigned)&PORTD*8)+3;
static volatile bit RD4                 @ ((unsigned)&PORTD*8)+4;
static volatile bit RD5                 @ ((unsigned)&PORTD*8)+5;
static volatile bit RD6                 @ ((unsigned)&PORTD*8)+6;
static volatile bit RD7                 @ ((unsigned)&PORTD*8)+7;
static volatile bit AD0                 @ ((unsigned)&PORTD*8)+0;
static volatile bit AD1                 @ ((unsigned)&PORTD*8)+1;
static volatile bit AD2                 @ ((unsigned)&PORTD*8)+2;
static volatile bit AD3                 @ ((unsigned)&PORTD*8)+3;
static volatile bit AD4                 @ ((unsigned)&PORTD*8)+4;
static volatile bit AD5                 @ ((unsigned)&PORTD*8)+5;
static volatile bit AD6                 @ ((unsigned)&PORTD*8)+6;
static volatile bit AD7                 @ ((unsigned)&PORTD*8)+7;
static volatile bit PSP0                @ ((unsigned)&PORTD*8)+0;
static volatile bit PSP1                @ ((unsigned)&PORTD*8)+1;
static volatile bit PSP2                @ ((unsigned)&PORTD*8)+2;
static volatile bit PSP3                @ ((unsigned)&PORTD*8)+3;
static volatile bit PSP4                @ ((unsigned)&PORTD*8)+4;
static volatile bit PSP5                @ ((unsigned)&PORTD*8)+5;
static volatile bit PSP6                @ ((unsigned)&PORTD*8)+6;
static volatile bit PSP7                @ ((unsigned)&PORTD*8)+7;
static volatile bit CTPLS               @ ((unsigned)&PORTD*8)+0;
static volatile bit T5CKI               @ ((unsigned)&PORTD*8)+1;
static volatile bit SDO2                @ ((unsigned)&PORTD*8)+4;
static volatile bit SDI2                @ ((unsigned)&PORTD*8)+5;
static volatile bit SCK2                @ ((unsigned)&PORTD*8)+6;
static volatile bit nSS2                @ ((unsigned)&PORTD*8)+7;
static volatile bit T7G                 @ ((unsigned)&PORTD*8)+1;
static volatile bit SDA2                @ ((unsigned)&PORTD*8)+5;
static volatile bit SCL2                @ ((unsigned)&PORTD*8)+6;

// Register: PORTE
static volatile unsigned char           PORTE               @ 0xF84;
// bit and bitfield definitions
static volatile bit RE0                 @ ((unsigned)&PORTE*8)+0;
static volatile bit RE1                 @ ((unsigned)&PORTE*8)+1;
static volatile bit RE2                 @ ((unsigned)&PORTE*8)+2;
static volatile bit RE3                 @ ((unsigned)&PORTE*8)+3;
static volatile bit RE4                 @ ((unsigned)&PORTE*8)+4;
static volatile bit RE5                 @ ((unsigned)&PORTE*8)+5;
static volatile bit RE6                 @ ((unsigned)&PORTE*8)+6;
static volatile bit RE7                 @ ((unsigned)&PORTE*8)+7;
static volatile bit AD8                 @ ((unsigned)&PORTE*8)+0;
static volatile bit AD9                 @ ((unsigned)&PORTE*8)+1;
static volatile bit AD10                @ ((unsigned)&PORTE*8)+2;
static volatile bit AD11                @ ((unsigned)&PORTE*8)+3;
static volatile bit AD12                @ ((unsigned)&PORTE*8)+4;
static volatile bit AD13                @ ((unsigned)&PORTE*8)+5;
static volatile bit AD14                @ ((unsigned)&PORTE*8)+6;
static volatile bit AD15                @ ((unsigned)&PORTE*8)+7;
static volatile bit P2D                 @ ((unsigned)&PORTE*8)+0;
static volatile bit P2C                 @ ((unsigned)&PORTE*8)+1;
static volatile bit P2B                 @ ((unsigned)&PORTE*8)+2;
static volatile bit P3C                 @ ((unsigned)&PORTE*8)+3;
static volatile bit P3B                 @ ((unsigned)&PORTE*8)+4;
static volatile bit P1C                 @ ((unsigned)&PORTE*8)+5;
static volatile bit P1B                 @ ((unsigned)&PORTE*8)+6;
//static volatile bit P2A                @ ((unsigned)&PORTE*8)+7;
static volatile bit CCP10               @ ((unsigned)&PORTE*8)+2;
static volatile bit CCP9                @ ((unsigned)&PORTE*8)+3;
static volatile bit CCP8                @ ((unsigned)&PORTE*8)+4;
static volatile bit CCP7                @ ((unsigned)&PORTE*8)+5;
static volatile bit CCP6                @ ((unsigned)&PORTE*8)+6;
//static volatile bit CCP2               @ ((unsigned)&PORTE*8)+7;
static volatile bit nRD                 @ ((unsigned)&PORTE*8)+0;
static volatile bit nWR                 @ ((unsigned)&PORTE*8)+1;
static volatile bit nCS                 @ ((unsigned)&PORTE*8)+2;
static volatile bit REFO                @ ((unsigned)&PORTE*8)+3;

// Register: PORTF
static volatile unsigned char           PORTF               @ 0xF85;
// bit and bitfield definitions
static volatile bit RF1                 @ ((unsigned)&PORTF*8)+1;
static volatile bit RF2                 @ ((unsigned)&PORTF*8)+2;
static volatile bit RF3                 @ ((unsigned)&PORTF*8)+3;
static volatile bit RF4                 @ ((unsigned)&PORTF*8)+4;
static volatile bit RF5                 @ ((unsigned)&PORTF*8)+5;
static volatile bit RF6                 @ ((unsigned)&PORTF*8)+6;
static volatile bit RF7                 @ ((unsigned)&PORTF*8)+7;
static volatile bit AN6                 @ ((unsigned)&PORTF*8)+1;
static volatile bit AN7                 @ ((unsigned)&PORTF*8)+2;
static volatile bit AN8                 @ ((unsigned)&PORTF*8)+3;
static volatile bit AN9                 @ ((unsigned)&PORTF*8)+4;
static volatile bit AN10                @ ((unsigned)&PORTF*8)+5;
static volatile bit AN11                @ ((unsigned)&PORTF*8)+6;
static volatile bit AN5                 @ ((unsigned)&PORTF*8)+7;
static volatile bit C2OUT               @ ((unsigned)&PORTF*8)+1;
static volatile bit C1OUT               @ ((unsigned)&PORTF*8)+2;
static volatile bit C2INB               @ ((unsigned)&PORTF*8)+3;
static volatile bit C2INA               @ ((unsigned)&PORTF*8)+4;
static volatile bit C1INB               @ ((unsigned)&PORTF*8)+5;
static volatile bit C1INA               @ ((unsigned)&PORTF*8)+6;
static volatile bit SS1                 @ ((unsigned)&PORTF*8)+7;
static volatile bit CTDIN               @ ((unsigned)&PORTF*8)+1;
static volatile bit CTMUI               @ ((unsigned)&PORTF*8)+3;
static volatile bit CVREF               @ ((unsigned)&PORTF*8)+5;

// Register: PORTG
static volatile unsigned char           PORTG               @ 0xF86;
// bit and bitfield definitions
static volatile bit RG0                 @ ((unsigned)&PORTG*8)+0;
static volatile bit RG1                 @ ((unsigned)&PORTG*8)+1;
static volatile bit RG2                 @ ((unsigned)&PORTG*8)+2;
static volatile bit RG3                 @ ((unsigned)&PORTG*8)+3;
static volatile bit RG4                 @ ((unsigned)&PORTG*8)+4;
static volatile bit RG5                 @ ((unsigned)&PORTG*8)+5;
static volatile bit CCP3                @ ((unsigned)&PORTG*8)+0;
static volatile bit C3OUT               @ ((unsigned)&PORTG*8)+1;
static volatile bit C3INA               @ ((unsigned)&PORTG*8)+2;
static volatile bit C3INB               @ ((unsigned)&PORTG*8)+3;
static volatile bit C3INC               @ ((unsigned)&PORTG*8)+4;
static volatile bit PA3                 @ ((unsigned)&PORTG*8)+0;
static volatile bit TX2                 @ ((unsigned)&PORTG*8)+1;
static volatile bit RX2                 @ ((unsigned)&PORTG*8)+2;
static volatile bit PD3                 @ ((unsigned)&PORTG*8)+3;
static volatile bit PD1                 @ ((unsigned)&PORTG*8)+4;
static volatile bit AN19                @ ((unsigned)&PORTG*8)+1;
static volatile bit AN18                @ ((unsigned)&PORTG*8)+2;
static volatile bit AN17                @ ((unsigned)&PORTG*8)+3;
static volatile bit AN16                @ ((unsigned)&PORTG*8)+4;
static volatile bit CK2                 @ ((unsigned)&PORTG*8)+1;
static volatile bit DT2                 @ ((unsigned)&PORTG*8)+2;
static volatile bit CCP4                @ ((unsigned)&PORTG*8)+3;
static volatile bit CCP5                @ ((unsigned)&PORTG*8)+4;
static volatile bit T7CKI               @ ((unsigned)&PORTG*8)+4;
static volatile bit T5G                 @ ((unsigned)&PORTG*8)+4;
static volatile bit RTCC                @ ((unsigned)&PORTG*8)+4;

// Register: LATA
static volatile unsigned char           LATA                @ 0xF89;
// bit and bitfield definitions
static volatile bit LATA0               @ ((unsigned)&LATA*8)+0;
static volatile bit LATA1               @ ((unsigned)&LATA*8)+1;
static volatile bit LATA2               @ ((unsigned)&LATA*8)+2;
static volatile bit LATA3               @ ((unsigned)&LATA*8)+3;
static volatile bit LATA4               @ ((unsigned)&LATA*8)+4;
static volatile bit LATA5               @ ((unsigned)&LATA*8)+5;
static volatile bit LATA6               @ ((unsigned)&LATA*8)+6;
static volatile bit LATA7               @ ((unsigned)&LATA*8)+7;

// Register: LATB
static volatile unsigned char           LATB                @ 0xF8A;
// bit and bitfield definitions
static volatile bit LATB0               @ ((unsigned)&LATB*8)+0;
static volatile bit LATB1               @ ((unsigned)&LATB*8)+1;
static volatile bit LATB2               @ ((unsigned)&LATB*8)+2;
static volatile bit LATB3               @ ((unsigned)&LATB*8)+3;
static volatile bit LATB4               @ ((unsigned)&LATB*8)+4;
static volatile bit LATB5               @ ((unsigned)&LATB*8)+5;
static volatile bit LATB6               @ ((unsigned)&LATB*8)+6;
static volatile bit LATB7               @ ((unsigned)&LATB*8)+7;

// Register: LATC
static volatile unsigned char           LATC                @ 0xF8B;
// bit and bitfield definitions
static volatile bit LATC0               @ ((unsigned)&LATC*8)+0;
static volatile bit LATC1               @ ((unsigned)&LATC*8)+1;
static volatile bit LATC2               @ ((unsigned)&LATC*8)+2;
static volatile bit LATC3               @ ((unsigned)&LATC*8)+3;
static volatile bit LATC4               @ ((unsigned)&LATC*8)+4;
static volatile bit LATC5               @ ((unsigned)&LATC*8)+5;
static volatile bit LATC6               @ ((unsigned)&LATC*8)+6;
static volatile bit LATC7               @ ((unsigned)&LATC*8)+7;

// Register: LATD
static volatile unsigned char           LATD                @ 0xF8C;
// bit and bitfield definitions
static volatile bit LATD0               @ ((unsigned)&LATD*8)+0;
static volatile bit LATD1               @ ((unsigned)&LATD*8)+1;
static volatile bit LATD2               @ ((unsigned)&LATD*8)+2;
static volatile bit LATD3               @ ((unsigned)&LATD*8)+3;
static volatile bit LATD4               @ ((unsigned)&LATD*8)+4;
static volatile bit LATD5               @ ((unsigned)&LATD*8)+5;
static volatile bit LATD6               @ ((unsigned)&LATD*8)+6;
static volatile bit LATD7               @ ((unsigned)&LATD*8)+7;

// Register: LATE
static volatile unsigned char           LATE                @ 0xF8D;
// bit and bitfield definitions
static volatile bit LATE0               @ ((unsigned)&LATE*8)+0;
static volatile bit LATE1               @ ((unsigned)&LATE*8)+1;
static volatile bit LATE2               @ ((unsigned)&LATE*8)+2;
static volatile bit LATE3               @ ((unsigned)&LATE*8)+3;
static volatile bit LATE4               @ ((unsigned)&LATE*8)+4;
static volatile bit LATE5               @ ((unsigned)&LATE*8)+5;
static volatile bit LATE6               @ ((unsigned)&LATE*8)+6;
static volatile bit LATE7               @ ((unsigned)&LATE*8)+7;

// Register: LATF
static volatile unsigned char           LATF                @ 0xF8E;
// bit and bitfield definitions
static volatile bit LATF1               @ ((unsigned)&LATF*8)+1;
static volatile bit LATF2               @ ((unsigned)&LATF*8)+2;
static volatile bit LATF3               @ ((unsigned)&LATF*8)+3;
static volatile bit LATF4               @ ((unsigned)&LATF*8)+4;
static volatile bit LATF5               @ ((unsigned)&LATF*8)+5;
static volatile bit LATF6               @ ((unsigned)&LATF*8)+6;
static volatile bit LATF7               @ ((unsigned)&LATF*8)+7;

// Register: LATG
static volatile unsigned char           LATG                @ 0xF8F;
// bit and bitfield definitions
static volatile bit LATG0               @ ((unsigned)&LATG*8)+0;
static volatile bit LATG1               @ ((unsigned)&LATG*8)+1;
static volatile bit LATG2               @ ((unsigned)&LATG*8)+2;
static volatile bit LATG3               @ ((unsigned)&LATG*8)+3;
static volatile bit LATG4               @ ((unsigned)&LATG*8)+4;

// Register: TRISA
static volatile unsigned char           TRISA               @ 0xF92;
// bit and bitfield definitions
static volatile bit TRISA0              @ ((unsigned)&TRISA*8)+0;
static volatile bit TRISA1              @ ((unsigned)&TRISA*8)+1;
static volatile bit TRISA2              @ ((unsigned)&TRISA*8)+2;
static volatile bit TRISA3              @ ((unsigned)&TRISA*8)+3;
static volatile bit TRISA4              @ ((unsigned)&TRISA*8)+4;
static volatile bit TRISA5              @ ((unsigned)&TRISA*8)+5;
static volatile bit TRISA6              @ ((unsigned)&TRISA*8)+6;
static volatile bit TRISA7              @ ((unsigned)&TRISA*8)+7;

// Register: TRISB
static volatile unsigned char           TRISB               @ 0xF93;
// bit and bitfield definitions
static volatile bit TRISB0              @ ((unsigned)&TRISB*8)+0;
static volatile bit TRISB1              @ ((unsigned)&TRISB*8)+1;
static volatile bit TRISB2              @ ((unsigned)&TRISB*8)+2;
static volatile bit TRISB3              @ ((unsigned)&TRISB*8)+3;
static volatile bit TRISB4              @ ((unsigned)&TRISB*8)+4;
static volatile bit TRISB5              @ ((unsigned)&TRISB*8)+5;
static volatile bit TRISB6              @ ((unsigned)&TRISB*8)+6;
static volatile bit TRISB7              @ ((unsigned)&TRISB*8)+7;

// Register: TRISC
static volatile unsigned char           TRISC               @ 0xF94;
// bit and bitfield definitions
static volatile bit TRISC0              @ ((unsigned)&TRISC*8)+0;
static volatile bit TRISC1              @ ((unsigned)&TRISC*8)+1;
static volatile bit TRISC2              @ ((unsigned)&TRISC*8)+2;
static volatile bit TRISC3              @ ((unsigned)&TRISC*8)+3;
static volatile bit TRISC4              @ ((unsigned)&TRISC*8)+4;
static volatile bit TRISC5              @ ((unsigned)&TRISC*8)+5;
static volatile bit TRISC6              @ ((unsigned)&TRISC*8)+6;
static volatile bit TRISC7              @ ((unsigned)&TRISC*8)+7;

// Register: TRISD
static volatile unsigned char           TRISD               @ 0xF95;
// bit and bitfield definitions
static volatile bit TRISD0              @ ((unsigned)&TRISD*8)+0;
static volatile bit TRISD1              @ ((unsigned)&TRISD*8)+1;
static volatile bit TRISD2              @ ((unsigned)&TRISD*8)+2;
static volatile bit TRISD3              @ ((unsigned)&TRISD*8)+3;
static volatile bit TRISD4              @ ((unsigned)&TRISD*8)+4;
static volatile bit TRISD5              @ ((unsigned)&TRISD*8)+5;
static volatile bit TRISD6              @ ((unsigned)&TRISD*8)+6;
static volatile bit TRISD7              @ ((unsigned)&TRISD*8)+7;

// Register: TRISE
static volatile unsigned char           TRISE               @ 0xF96;
// bit and bitfield definitions
static volatile bit TRISE1              @ ((unsigned)&TRISE*8)+1;
static volatile bit TRISE2              @ ((unsigned)&TRISE*8)+2;
static volatile bit TRISE3              @ ((unsigned)&TRISE*8)+3;
static volatile bit TRISE4              @ ((unsigned)&TRISE*8)+4;
static volatile bit TRISE5              @ ((unsigned)&TRISE*8)+5;
static volatile bit TRISE6              @ ((unsigned)&TRISE*8)+6;
static volatile bit TRISE7              @ ((unsigned)&TRISE*8)+7;

// Register: TRISF
static volatile unsigned char           TRISF               @ 0xF97;
// bit and bitfield definitions
static volatile bit TRISF1              @ ((unsigned)&TRISF*8)+1;
static volatile bit TRISF2              @ ((unsigned)&TRISF*8)+2;
static volatile bit TRISF3              @ ((unsigned)&TRISF*8)+3;
static volatile bit TRISF4              @ ((unsigned)&TRISF*8)+4;
static volatile bit TRISF5              @ ((unsigned)&TRISF*8)+5;
static volatile bit TRISF6              @ ((unsigned)&TRISF*8)+6;
static volatile bit TRISF7              @ ((unsigned)&TRISF*8)+7;

// Register: TRISG
static volatile unsigned char           TRISG               @ 0xF98;
// bit and bitfield definitions
static volatile bit TRISG0              @ ((unsigned)&TRISG*8)+0;
static volatile bit TRISG1              @ ((unsigned)&TRISG*8)+1;
static volatile bit TRISG2              @ ((unsigned)&TRISG*8)+2;
static volatile bit TRISG3              @ ((unsigned)&TRISG*8)+3;
static volatile bit TRISG4              @ ((unsigned)&TRISG*8)+4;

// Register: OSCTUNE
static volatile unsigned char           OSCTUNE             @ 0xF9B;
// bit and bitfield definitions
static volatile bit PLLEN               @ ((unsigned)&OSCTUNE*8)+6;
static volatile bit INTSRC              @ ((unsigned)&OSCTUNE*8)+7;
static volatile bit TUN0                @ ((unsigned)&OSCTUNE*8)+0;
static volatile bit TUN1                @ ((unsigned)&OSCTUNE*8)+1;
static volatile bit TUN2                @ ((unsigned)&OSCTUNE*8)+2;
static volatile bit TUN3                @ ((unsigned)&OSCTUNE*8)+3;
static volatile bit TUN4                @ ((unsigned)&OSCTUNE*8)+4;
static volatile bit TUN5                @ ((unsigned)&OSCTUNE*8)+5;

// Register: PSTR1CON
static volatile unsigned char           PSTR1CON            @ 0xF9C;
// bit and bitfield definitions
//static volatile bit STRA               @ ((unsigned)&PSTR1CON*8)+0;
//static volatile bit STRB               @ ((unsigned)&PSTR1CON*8)+1;
//static volatile bit STRC               @ ((unsigned)&PSTR1CON*8)+2;
//static volatile bit STRD               @ ((unsigned)&PSTR1CON*8)+3;
//static volatile bit STRSYNC            @ ((unsigned)&PSTR1CON*8)+4;
//static volatile bit CMPL0              @ ((unsigned)&PSTR1CON*8)+6;
//static volatile bit CMPL1              @ ((unsigned)&PSTR1CON*8)+7;

// Register: PIE1
static volatile unsigned char           PIE1                @ 0xF9D;
// bit and bitfield definitions
static volatile bit TMR1IE              @ ((unsigned)&PIE1*8)+0;
static volatile bit TMR2IE              @ ((unsigned)&PIE1*8)+1;
static volatile bit TMR1GIE             @ ((unsigned)&PIE1*8)+2;
static volatile bit SSP1IE              @ ((unsigned)&PIE1*8)+3;
static volatile bit TX1IE               @ ((unsigned)&PIE1*8)+4;
static volatile bit RC1IE               @ ((unsigned)&PIE1*8)+5;
static volatile bit ADIE                @ ((unsigned)&PIE1*8)+6;
static volatile bit PSPIE               @ ((unsigned)&PIE1*8)+7;
static volatile bit SSPIE               @ ((unsigned)&PIE1*8)+3;
static volatile bit TXIE                @ ((unsigned)&PIE1*8)+4;
static volatile bit RCIE                @ ((unsigned)&PIE1*8)+5;

// Register: PIR1
static volatile unsigned char           PIR1                @ 0xF9E;
// bit and bitfield definitions
static volatile bit TMR1IF              @ ((unsigned)&PIR1*8)+0;
static volatile bit TMR2IF              @ ((unsigned)&PIR1*8)+1;
static volatile bit TMR1GIF             @ ((unsigned)&PIR1*8)+2;
static volatile bit SSP1IF              @ ((unsigned)&PIR1*8)+3;
static volatile bit TX1IF               @ ((unsigned)&PIR1*8)+4;
static volatile bit RC1IF               @ ((unsigned)&PIR1*8)+5;
static volatile bit ADIF                @ ((unsigned)&PIR1*8)+6;
static volatile bit PSPIF               @ ((unsigned)&PIR1*8)+7;
static volatile bit SSPIF               @ ((unsigned)&PIR1*8)+3;
static volatile bit TXIF                @ ((unsigned)&PIR1*8)+4;
static volatile bit RCIF                @ ((unsigned)&PIR1*8)+5;

// Register: IPR1
static volatile unsigned char           IPR1                @ 0xF9F;
// bit and bitfield definitions
static volatile bit TMR1IP              @ ((unsigned)&IPR1*8)+0;
static volatile bit TMR2IP              @ ((unsigned)&IPR1*8)+1;
static volatile bit TMR1GIP             @ ((unsigned)&IPR1*8)+2;
static volatile bit SSP1IP              @ ((unsigned)&IPR1*8)+3;
static volatile bit TX1IP               @ ((unsigned)&IPR1*8)+4;
static volatile bit RC1IP               @ ((unsigned)&IPR1*8)+5;
static volatile bit ADIP                @ ((unsigned)&IPR1*8)+6;
static volatile bit PSPIP               @ ((unsigned)&IPR1*8)+7;
static volatile bit SSPIP               @ ((unsigned)&IPR1*8)+3;
static volatile bit TXIP                @ ((unsigned)&IPR1*8)+4;
static volatile bit RCIP                @ ((unsigned)&IPR1*8)+5;

// Register: PIE2
static volatile unsigned char           PIE2                @ 0xFA0;
// bit and bitfield definitions
static volatile bit TMR3GIE             @ ((unsigned)&PIE2*8)+0;
static volatile bit TMR3IE              @ ((unsigned)&PIE2*8)+1;
static volatile bit HLVDIE              @ ((unsigned)&PIE2*8)+2;
static volatile bit BCL1IE              @ ((unsigned)&PIE2*8)+3;
static volatile bit BCL2IE              @ ((unsigned)&PIE2*8)+4;
static volatile bit SSP2IE              @ ((unsigned)&PIE2*8)+5;
static volatile bit OSCFIE              @ ((unsigned)&PIE2*8)+7;
static volatile bit LVDIE               @ ((unsigned)&PIE2*8)+2;
static volatile bit BCLIE               @ ((unsigned)&PIE2*8)+3;

// Register: PIR2
static volatile unsigned char           PIR2                @ 0xFA1;
// bit and bitfield definitions
static volatile bit TMR3GIF             @ ((unsigned)&PIR2*8)+0;
static volatile bit TMR3IF              @ ((unsigned)&PIR2*8)+1;
static volatile bit HLVDIF              @ ((unsigned)&PIR2*8)+2;
static volatile bit BCL1IF              @ ((unsigned)&PIR2*8)+3;
static volatile bit BCL2IF              @ ((unsigned)&PIR2*8)+4;
static volatile bit SSP2IF              @ ((unsigned)&PIR2*8)+5;
static volatile bit OSCFIF              @ ((unsigned)&PIR2*8)+7;
static volatile bit LVDIF               @ ((unsigned)&PIR2*8)+2;
static volatile bit BCLIF               @ ((unsigned)&PIR2*8)+3;

// Register: IPR2
static volatile unsigned char           IPR2                @ 0xFA2;
// bit and bitfield definitions
static volatile bit TMR3GIP             @ ((unsigned)&IPR2*8)+0;
static volatile bit TMR3IP              @ ((unsigned)&IPR2*8)+1;
static volatile bit HLVDIP              @ ((unsigned)&IPR2*8)+2;
static volatile bit BCL1IP              @ ((unsigned)&IPR2*8)+3;
static volatile bit BCL2IP              @ ((unsigned)&IPR2*8)+4;
static volatile bit SSP2IP              @ ((unsigned)&IPR2*8)+5;
static volatile bit OSCFIP              @ ((unsigned)&IPR2*8)+7;
static volatile bit LVDIP               @ ((unsigned)&IPR2*8)+2;
static volatile bit BCLIP               @ ((unsigned)&IPR2*8)+3;

// Register: PIE3
static volatile unsigned char           PIE3                @ 0xFA3;
// bit and bitfield definitions
static volatile bit RTCCIE              @ ((unsigned)&PIE3*8)+0;
static volatile bit CCP1IE              @ ((unsigned)&PIE3*8)+1;
static volatile bit CCP2IE              @ ((unsigned)&PIE3*8)+2;
static volatile bit CTMUIE              @ ((unsigned)&PIE3*8)+3;
static volatile bit TX2IE               @ ((unsigned)&PIE3*8)+4;
static volatile bit RC2IE               @ ((unsigned)&PIE3*8)+5;
static volatile bit TMR5GIE             @ ((unsigned)&PIE3*8)+7;

// Register: PIR3
static volatile unsigned char           PIR3                @ 0xFA4;
// bit and bitfield definitions
static volatile bit RTCCIF              @ ((unsigned)&PIR3*8)+0;
static volatile bit CCP1IF              @ ((unsigned)&PIR3*8)+1;
static volatile bit CCP2IF              @ ((unsigned)&PIR3*8)+2;
static volatile bit CTMUIF              @ ((unsigned)&PIR3*8)+3;
static volatile bit TX2IF               @ ((unsigned)&PIR3*8)+4;
static volatile bit RC2IF               @ ((unsigned)&PIR3*8)+5;
static volatile bit TMR5GIF             @ ((unsigned)&PIR3*8)+7;

// Register: IPR3
static volatile unsigned char           IPR3                @ 0xFA5;
// bit and bitfield definitions
static volatile bit RTCCIP              @ ((unsigned)&IPR3*8)+0;
static volatile bit CCP1IP              @ ((unsigned)&IPR3*8)+1;
static volatile bit CCP2IP              @ ((unsigned)&IPR3*8)+2;
static volatile bit CTMUIP              @ ((unsigned)&IPR3*8)+3;
static volatile bit TX2IP               @ ((unsigned)&IPR3*8)+4;
static volatile bit RC2IP               @ ((unsigned)&IPR3*8)+5;
static volatile bit TMR5GIP             @ ((unsigned)&IPR3*8)+7;

// Register: PIR6
static volatile unsigned char           PIR6                @ 0xFA6;
// bit and bitfield definitions
static volatile bit CMP1IF              @ ((unsigned)&PIR6*8)+0;
static volatile bit CMP2IF              @ ((unsigned)&PIR6*8)+1;
static volatile bit CMP3IF              @ ((unsigned)&PIR6*8)+2;
static volatile bit EEIF                @ ((unsigned)&PIR6*8)+4;

// Register: PSPCON
static volatile unsigned char           PSPCON              @ 0xFA7;
// bit and bitfield definitions
static volatile bit PSPMODE             @ ((unsigned)&PSPCON*8)+4;
static volatile bit IBOV                @ ((unsigned)&PSPCON*8)+5;
static volatile bit OBF                 @ ((unsigned)&PSPCON*8)+6;
static volatile bit IBF                 @ ((unsigned)&PSPCON*8)+7;

// Register: HLVDCON
static volatile unsigned char           HLVDCON             @ 0xFA8;
// bit and bitfield definitions
static volatile bit HLVDEN              @ ((unsigned)&HLVDCON*8)+4;
static volatile bit IRVST               @ ((unsigned)&HLVDCON*8)+5;
static volatile bit BGVST               @ ((unsigned)&HLVDCON*8)+6;
static volatile bit VDIRMAG             @ ((unsigned)&HLVDCON*8)+7;
static volatile bit HLVDL0              @ ((unsigned)&HLVDCON*8)+0;
static volatile bit HLVDL1              @ ((unsigned)&HLVDCON*8)+1;
static volatile bit HLVDL2              @ ((unsigned)&HLVDCON*8)+2;
static volatile bit HLVDL3              @ ((unsigned)&HLVDCON*8)+3;

// Register: IPR6
static volatile unsigned char           IPR6                @ 0xFA9;
// bit and bitfield definitions
static volatile bit CMP1IP              @ ((unsigned)&IPR6*8)+0;
static volatile bit CMP2IP              @ ((unsigned)&IPR6*8)+1;
static volatile bit CMP3IP              @ ((unsigned)&IPR6*8)+2;
static volatile bit EEIP                @ ((unsigned)&IPR6*8)+4;

// Register: T1GCON
static volatile unsigned char           T1GCON              @ 0xFAA;
// bit and bitfield definitions
static volatile bit T1GVAL              @ ((unsigned)&T1GCON*8)+2;
static volatile bit T1GGO_nT1DONE       @ ((unsigned)&T1GCON*8)+3;
static volatile bit T1GSPM              @ ((unsigned)&T1GCON*8)+4;
static volatile bit T1GTM               @ ((unsigned)&T1GCON*8)+5;
static volatile bit T1GPOL              @ ((unsigned)&T1GCON*8)+6;
static volatile bit TMR1GE              @ ((unsigned)&T1GCON*8)+7;
static volatile bit T1GSS0              @ ((unsigned)&T1GCON*8)+0;
static volatile bit T1GSS1              @ ((unsigned)&T1GCON*8)+1;
static volatile bit T1GGO               @ ((unsigned)&T1GCON*8)+3;
static volatile bit nT1DONE             @ ((unsigned)&T1GCON*8)+3;

// Register: RCSTA1
static volatile unsigned char           RCSTA1              @ 0xFAB;
static volatile unsigned char           RCSTA               @ 0xFAB;
// bit and bitfield definitions
//static volatile bit RX9D               @ ((unsigned)&RCSTA1*8)+0;
//static volatile bit OERR               @ ((unsigned)&RCSTA1*8)+1;
//static volatile bit FERR               @ ((unsigned)&RCSTA1*8)+2;
//static volatile bit ADDEN              @ ((unsigned)&RCSTA1*8)+3;
//static volatile bit CREN               @ ((unsigned)&RCSTA1*8)+4;
//static volatile bit SREN               @ ((unsigned)&RCSTA1*8)+5;
//static volatile bit RX9                @ ((unsigned)&RCSTA1*8)+6;
//static volatile bit SPEN               @ ((unsigned)&RCSTA1*8)+7;
static volatile bit RCD8                @ ((unsigned)&RCSTA1*8)+0;
static volatile bit ADEN                @ ((unsigned)&RCSTA1*8)+3;
static volatile bit RC9                 @ ((unsigned)&RCSTA1*8)+6;
static volatile bit nRC8                @ ((unsigned)&RCSTA1*8)+6;
static volatile bit RC8_9               @ ((unsigned)&RCSTA1*8)+6;

// Register: TXSTA1
static volatile unsigned char           TXSTA1              @ 0xFAC;
static volatile unsigned char           TXSTA               @ 0xFAC;
// bit and bitfield definitions
//static volatile bit TX9D               @ ((unsigned)&TXSTA1*8)+0;
//static volatile bit TRMT               @ ((unsigned)&TXSTA1*8)+1;
//static volatile bit BRGH               @ ((unsigned)&TXSTA1*8)+2;
//static volatile bit SENDB              @ ((unsigned)&TXSTA1*8)+3;
//static volatile bit SYNC               @ ((unsigned)&TXSTA1*8)+4;
//static volatile bit TXEN               @ ((unsigned)&TXSTA1*8)+5;
//static volatile bit TX9                @ ((unsigned)&TXSTA1*8)+6;
//static volatile bit CSRC               @ ((unsigned)&TXSTA1*8)+7;
static volatile bit TXD8                @ ((unsigned)&TXSTA1*8)+0;
static volatile bit TX8_9               @ ((unsigned)&TXSTA1*8)+6;
static volatile bit nTX8                @ ((unsigned)&TXSTA1*8)+6;

// Register: TXREG1
static volatile unsigned char           TXREG1              @ 0xFAD;
static volatile unsigned char           TXREG               @ 0xFAD;
// bit and bitfield definitions

// Register: RCREG1
static volatile unsigned char           RCREG1              @ 0xFAE;
static volatile unsigned char           RCREG               @ 0xFAE;
// bit and bitfield definitions

// Register: SPBRG1
static volatile unsigned char           SPBRG1              @ 0xFAF;
static volatile unsigned char           SPBRG               @ 0xFAF;
// bit and bitfield definitions

// Register: T3GCON
static volatile unsigned char           T3GCON              @ 0xFB0;
// bit and bitfield definitions
static volatile bit T3GVAL              @ ((unsigned)&T3GCON*8)+2;
static volatile bit T3GGO_nT3DONE       @ ((unsigned)&T3GCON*8)+3;
static volatile bit T3GSPM              @ ((unsigned)&T3GCON*8)+4;
static volatile bit T3GTM               @ ((unsigned)&T3GCON*8)+5;
static volatile bit T3GPOL              @ ((unsigned)&T3GCON*8)+6;
static volatile bit TMR3GE              @ ((unsigned)&T3GCON*8)+7;
static volatile bit T3GSS0              @ ((unsigned)&T3GCON*8)+0;
static volatile bit T3GSS1              @ ((unsigned)&T3GCON*8)+1;
static volatile bit T3GGO               @ ((unsigned)&T3GCON*8)+3;
static volatile bit nT3DONE             @ ((unsigned)&T3GCON*8)+3;

// Register: T3CON
static volatile unsigned char           T3CON               @ 0xFB1;
// bit and bitfield definitions
static volatile bit TMR3ON              @ ((unsigned)&T3CON*8)+0;
//static volatile bit RD16               @ ((unsigned)&T3CON*8)+1;
static volatile bit nT3SYNC             @ ((unsigned)&T3CON*8)+2;
//static volatile bit SOSCEN             @ ((unsigned)&T3CON*8)+3;
static volatile bit T3CKPS0             @ ((unsigned)&T3CON*8)+4;
static volatile bit T3CKPS1             @ ((unsigned)&T3CON*8)+5;
static volatile bit TMR3CS0             @ ((unsigned)&T3CON*8)+6;
static volatile bit TMR3CS1             @ ((unsigned)&T3CON*8)+7;

// Register: TMR3L
static volatile unsigned char           TMR3L               @ 0xFB2;
// bit and bitfield definitions

// Register: TMR3H
static volatile unsigned char           TMR3H               @ 0xFB3;
// bit and bitfield definitions

// Register: TMR3
static volatile unsigned int            TMR3                @ 0xFB2;

// Register: CMSTAT
static volatile unsigned char           CMSTAT              @ 0xFB4;
static volatile unsigned char           CMSTATUS            @ 0xFB4;
// bit and bitfield definitions
static volatile bit CMP1OUT             @ ((unsigned)&CMSTAT*8)+5;
static volatile bit CMP2OUT             @ ((unsigned)&CMSTAT*8)+6;
static volatile bit CMP3OUT             @ ((unsigned)&CMSTAT*8)+7;

// Register: CVRCON
static volatile unsigned char           CVRCON              @ 0xFB5;
// bit and bitfield definitions
static volatile bit CVRSS               @ ((unsigned)&CVRCON*8)+5;
static volatile bit CVROE               @ ((unsigned)&CVRCON*8)+6;
static volatile bit CVREN               @ ((unsigned)&CVRCON*8)+7;
static volatile bit CVR0                @ ((unsigned)&CVRCON*8)+0;
static volatile bit CVR1                @ ((unsigned)&CVRCON*8)+1;
static volatile bit CVR2                @ ((unsigned)&CVRCON*8)+2;
static volatile bit CVR3                @ ((unsigned)&CVRCON*8)+3;
static volatile bit CVR4                @ ((unsigned)&CVRCON*8)+4;

// Register: PIE4
static volatile unsigned char           PIE4                @ 0xFB6;
// bit and bitfield definitions
static volatile bit CCP3IE              @ ((unsigned)&PIE4*8)+0;
static volatile bit CCP4IE              @ ((unsigned)&PIE4*8)+1;
static volatile bit CCP5IE              @ ((unsigned)&PIE4*8)+2;
static volatile bit CCP6IE              @ ((unsigned)&PIE4*8)+3;
static volatile bit CCP7IE              @ ((unsigned)&PIE4*8)+4;
static volatile bit CCP8IE              @ ((unsigned)&PIE4*8)+5;

// Register: PIR4
static volatile unsigned char           PIR4                @ 0xFB7;
// bit and bitfield definitions
static volatile bit CCP3IF              @ ((unsigned)&PIR4*8)+0;
static volatile bit CCP4IF              @ ((unsigned)&PIR4*8)+1;
static volatile bit CCP5IF              @ ((unsigned)&PIR4*8)+2;
static volatile bit CCP6IF              @ ((unsigned)&PIR4*8)+3;
static volatile bit CCP7IF              @ ((unsigned)&PIR4*8)+4;
static volatile bit CCP8IF              @ ((unsigned)&PIR4*8)+5;

// Register: IPR4
static volatile unsigned char           IPR4                @ 0xFB8;
// bit and bitfield definitions
static volatile bit CCP3IP              @ ((unsigned)&IPR4*8)+0;
static volatile bit CCP4IP              @ ((unsigned)&IPR4*8)+1;
static volatile bit CCP5IP              @ ((unsigned)&IPR4*8)+2;
static volatile bit CCP6IP              @ ((unsigned)&IPR4*8)+3;
static volatile bit CCP7IP              @ ((unsigned)&IPR4*8)+4;
static volatile bit CCP8IP              @ ((unsigned)&IPR4*8)+5;

// Register: PIE5
static volatile unsigned char           PIE5                @ 0xFB9;
// bit and bitfield definitions
static volatile bit TMR4IE              @ ((unsigned)&PIE5*8)+0;
static volatile bit TMR5IE              @ ((unsigned)&PIE5*8)+1;
static volatile bit TMR6IE              @ ((unsigned)&PIE5*8)+2;
static volatile bit TMR8IE              @ ((unsigned)&PIE5*8)+4;

// Register: PIR5
static volatile unsigned char           PIR5                @ 0xFBA;
// bit and bitfield definitions
static volatile bit TMR4IF              @ ((unsigned)&PIR5*8)+0;
static volatile bit TMR5IF              @ ((unsigned)&PIR5*8)+1;
static volatile bit TMR6IF              @ ((unsigned)&PIR5*8)+2;
static volatile bit TMR8IF              @ ((unsigned)&PIR5*8)+4;

// Register: CCP1CON
static volatile unsigned char           CCP1CON             @ 0xFBB;
static volatile unsigned char           ECCP1CON            @ 0xFBB;
// bit and bitfield definitions
static volatile bit CCP1M0              @ ((unsigned)&CCP1CON*8)+0;
static volatile bit CCP1M1              @ ((unsigned)&CCP1CON*8)+1;
static volatile bit CCP1M2              @ ((unsigned)&CCP1CON*8)+2;
static volatile bit CCP1M3              @ ((unsigned)&CCP1CON*8)+3;
static volatile bit DC1B0               @ ((unsigned)&CCP1CON*8)+4;
static volatile bit DC1B1               @ ((unsigned)&CCP1CON*8)+5;
static volatile bit P1M0                @ ((unsigned)&CCP1CON*8)+6;
static volatile bit P1M1                @ ((unsigned)&CCP1CON*8)+7;
static volatile bit CCP1Y               @ ((unsigned)&CCP1CON*8)+4;
static volatile bit CCP1X               @ ((unsigned)&CCP1CON*8)+5;

// Register: CCPR1L
static volatile unsigned char           CCPR1L              @ 0xFBC;
// bit and bitfield definitions

// Register: CCPR1H
static volatile unsigned char           CCPR1H              @ 0xFBD;
// bit and bitfield definitions

// Register: CCPR1
static volatile unsigned int            CCPR1               @ 0xFBC;

// Register: ECCP1DEL
static volatile unsigned char           ECCP1DEL            @ 0xFBE;
static volatile unsigned char           PWM1CON             @ 0xFBE;
// bit and bitfield definitions
static volatile bit P1RSEN              @ ((unsigned)&ECCP1DEL*8)+7;
static volatile bit P1DC0               @ ((unsigned)&ECCP1DEL*8)+0;
static volatile bit P1DC1               @ ((unsigned)&ECCP1DEL*8)+1;
static volatile bit P1DC2               @ ((unsigned)&ECCP1DEL*8)+2;
static volatile bit P1DC3               @ ((unsigned)&ECCP1DEL*8)+3;
static volatile bit P1DC4               @ ((unsigned)&ECCP1DEL*8)+4;
static volatile bit P1DC5               @ ((unsigned)&ECCP1DEL*8)+5;
static volatile bit P1DC6               @ ((unsigned)&ECCP1DEL*8)+6;

// Register: ECCP1AS
static volatile unsigned char           ECCP1AS             @ 0xFBF;
// bit and bitfield definitions
static volatile bit ECCP1ASE            @ ((unsigned)&ECCP1AS*8)+7;
static volatile bit PSS1BD0             @ ((unsigned)&ECCP1AS*8)+0;
static volatile bit PSS1BD1             @ ((unsigned)&ECCP1AS*8)+1;
static volatile bit PSS1AC0             @ ((unsigned)&ECCP1AS*8)+2;
static volatile bit PSS1AC1             @ ((unsigned)&ECCP1AS*8)+3;
static volatile bit ECCP1AS0            @ ((unsigned)&ECCP1AS*8)+4;
static volatile bit ECCP1AS1            @ ((unsigned)&ECCP1AS*8)+5;
static volatile bit ECCP1AS2            @ ((unsigned)&ECCP1AS*8)+6;

// Register: ADCON2
static volatile unsigned char           ADCON2              @ 0xFC0;
// bit and bitfield definitions
static volatile bit ADFM                @ ((unsigned)&ADCON2*8)+7;
static volatile bit ADCS0               @ ((unsigned)&ADCON2*8)+0;
static volatile bit ADCS1               @ ((unsigned)&ADCON2*8)+1;
static volatile bit ADCS2               @ ((unsigned)&ADCON2*8)+2;
static volatile bit ACQT0               @ ((unsigned)&ADCON2*8)+3;
static volatile bit ACQT1               @ ((unsigned)&ADCON2*8)+4;
static volatile bit ACQT2               @ ((unsigned)&ADCON2*8)+5;

// Register: ADCON1
static volatile unsigned char           ADCON1              @ 0xFC1;
// bit and bitfield definitions
static volatile bit VNCFG               @ ((unsigned)&ADCON1*8)+3;
static volatile bit CHSN0               @ ((unsigned)&ADCON1*8)+0;
static volatile bit CHSN1               @ ((unsigned)&ADCON1*8)+1;
static volatile bit CHSN2               @ ((unsigned)&ADCON1*8)+2;
static volatile bit VCFG0               @ ((unsigned)&ADCON1*8)+4;
static volatile bit VCFG1               @ ((unsigned)&ADCON1*8)+5;
static volatile bit TRIGSEL0            @ ((unsigned)&ADCON1*8)+6;
static volatile bit TRIGSEL1            @ ((unsigned)&ADCON1*8)+7;

// Register: ADCON0
static volatile unsigned char           ADCON0              @ 0xFC2;
// bit and bitfield definitions
static volatile bit ADON                @ ((unsigned)&ADCON0*8)+0;
static volatile bit GO_nDONE            @ ((unsigned)&ADCON0*8)+1;
static volatile bit DONE                @ ((unsigned)&ADCON0*8)+1;
static volatile bit CHS0                @ ((unsigned)&ADCON0*8)+2;
static volatile bit CHS1                @ ((unsigned)&ADCON0*8)+3;
static volatile bit CHS2                @ ((unsigned)&ADCON0*8)+4;
static volatile bit CHS3                @ ((unsigned)&ADCON0*8)+5;
static volatile bit CHS4                @ ((unsigned)&ADCON0*8)+6;
static volatile bit GO                  @ ((unsigned)&ADCON0*8)+1;
static volatile bit nDONE               @ ((unsigned)&ADCON0*8)+1;

// Register: ADRESL
static volatile unsigned char           ADRESL              @ 0xFC3;
// bit and bitfield definitions

// Register: ADRESH
static volatile unsigned char           ADRESH              @ 0xFC4;
// bit and bitfield definitions

// Register: ADRES
static volatile unsigned int            ADRES               @ 0xFC3;

// Register: SSP1CON2
static volatile unsigned char           SSP1CON2            @ 0xFC5;
static volatile unsigned char           SSPCON2             @ 0xFC5;
// bit and bitfield definitions
//static volatile bit SEN                @ ((unsigned)&SSP1CON2*8)+0;
//static volatile bit RSEN               @ ((unsigned)&SSP1CON2*8)+1;
//static volatile bit PEN                @ ((unsigned)&SSP1CON2*8)+2;
//static volatile bit RCEN               @ ((unsigned)&SSP1CON2*8)+3;
//static volatile bit ACKEN              @ ((unsigned)&SSP1CON2*8)+4;
//static volatile bit ACKDT              @ ((unsigned)&SSP1CON2*8)+5;
//static volatile bit ACKSTAT            @ ((unsigned)&SSP1CON2*8)+6;
//static volatile bit GCEN               @ ((unsigned)&SSP1CON2*8)+7;
//static volatile bit ADMSK1             @ ((unsigned)&SSP1CON2*8)+1;
//static volatile bit ADMSK2             @ ((unsigned)&SSP1CON2*8)+2;
//static volatile bit ADMSK3             @ ((unsigned)&SSP1CON2*8)+3;
//static volatile bit ADMSK4             @ ((unsigned)&SSP1CON2*8)+4;
//static volatile bit ADMSK5             @ ((unsigned)&SSP1CON2*8)+5;

// Register: SSP1CON1
static volatile unsigned char           SSP1CON1            @ 0xFC6;
static volatile unsigned char           SSPCON1             @ 0xFC6;
// bit and bitfield definitions
//static volatile bit CKP                @ ((unsigned)&SSP1CON1*8)+4;
//static volatile bit SSPEN              @ ((unsigned)&SSP1CON1*8)+5;
//static volatile bit SSPOV              @ ((unsigned)&SSP1CON1*8)+6;
//static volatile bit WCOL               @ ((unsigned)&SSP1CON1*8)+7;
//static volatile bit SSPM0              @ ((unsigned)&SSP1CON1*8)+0;
//static volatile bit SSPM1              @ ((unsigned)&SSP1CON1*8)+1;
//static volatile bit SSPM2              @ ((unsigned)&SSP1CON1*8)+2;
//static volatile bit SSPM3              @ ((unsigned)&SSP1CON1*8)+3;

// Register: SSP1STAT
static volatile unsigned char           SSP1STAT            @ 0xFC7;
static volatile unsigned char           SSPSTAT             @ 0xFC7;
// bit and bitfield definitions
//static volatile bit BF                 @ ((unsigned)&SSP1STAT*8)+0;
//static volatile bit UA                 @ ((unsigned)&SSP1STAT*8)+1;
//static volatile bit R_nW               @ ((unsigned)&SSP1STAT*8)+2;
//static volatile bit S                  @ ((unsigned)&SSP1STAT*8)+3;
//static volatile bit P                  @ ((unsigned)&SSP1STAT*8)+4;
//static volatile bit D_nA               @ ((unsigned)&SSP1STAT*8)+5;
//static volatile bit CKE                @ ((unsigned)&SSP1STAT*8)+6;
//static volatile bit SMP                @ ((unsigned)&SSP1STAT*8)+7;
//static volatile bit R                  @ ((unsigned)&SSP1STAT*8)+2;
//static volatile bit D                  @ ((unsigned)&SSP1STAT*8)+5;
////static volatile bit R                  @ ((unsigned)&SSP1STAT*8)+2;
////static volatile bit D                  @ ((unsigned)&SSP1STAT*8)+5;
//static volatile bit R_W                @ ((unsigned)&SSP1STAT*8)+2;
//static volatile bit D_A                @ ((unsigned)&SSP1STAT*8)+5;
//static volatile bit nW                 @ ((unsigned)&SSP1STAT*8)+2;
//static volatile bit nA                 @ ((unsigned)&SSP1STAT*8)+5;
//static volatile bit nWRITE             @ ((unsigned)&SSP1STAT*8)+2;
//static volatile bit nADDRESS           @ ((unsigned)&SSP1STAT*8)+5;
//static volatile bit READ_WRITE         @ ((unsigned)&SSP1STAT*8)+2;
//static volatile bit DATA_ADDRESS       @ ((unsigned)&SSP1STAT*8)+5;
//static volatile bit I2C_READ           @ ((unsigned)&SSP1STAT*8)+2;
//static volatile bit I2C_START          @ ((unsigned)&SSP1STAT*8)+3;
//static volatile bit I2C_STOP           @ ((unsigned)&SSP1STAT*8)+4;
//static volatile bit I2C_DAT            @ ((unsigned)&SSP1STAT*8)+5;

// Register: SSP1ADD
static volatile unsigned char           SSP1ADD             @ 0xFC8;
static volatile unsigned char           SSPADD              @ 0xFC8;	// shared address with SSP1ADD
// bit and bitfield definitions

// Register: SSP1MSK
static volatile unsigned char           SSP1MSK             @ 0xFC8;	// shared address with SSP1ADD
// bit and bitfield definitions
//static volatile bit MSK0               @ ((unsigned)&SSP1MSK*8)+0;
//static volatile bit MSK1               @ ((unsigned)&SSP1MSK*8)+1;
//static volatile bit MSK2               @ ((unsigned)&SSP1MSK*8)+2;
//static volatile bit MSK3               @ ((unsigned)&SSP1MSK*8)+3;
//static volatile bit MSK4               @ ((unsigned)&SSP1MSK*8)+4;
//static volatile bit MSK5               @ ((unsigned)&SSP1MSK*8)+5;
//static volatile bit MSK6               @ ((unsigned)&SSP1MSK*8)+6;
//static volatile bit MSK7               @ ((unsigned)&SSP1MSK*8)+7;

// Register: SSP1BUF
static volatile unsigned char           SSP1BUF             @ 0xFC9;
static volatile unsigned char           SSPBUF              @ 0xFC9;
// bit and bitfield definitions

// Register: T2CON
static volatile unsigned char           T2CON               @ 0xFCA;
// bit and bitfield definitions
static volatile bit TMR2ON              @ ((unsigned)&T2CON*8)+2;
static volatile bit T2CKPS0             @ ((unsigned)&T2CON*8)+0;
static volatile bit T2CKPS1             @ ((unsigned)&T2CON*8)+1;
static volatile bit T2OUTPS0            @ ((unsigned)&T2CON*8)+3;
static volatile bit T2OUTPS1            @ ((unsigned)&T2CON*8)+4;
static volatile bit T2OUTPS2            @ ((unsigned)&T2CON*8)+5;
static volatile bit T2OUTPS3            @ ((unsigned)&T2CON*8)+6;

// Register: PR2
static volatile unsigned char           PR2                 @ 0xFCB;
// bit and bitfield definitions

// Register: TMR2
static volatile unsigned char           TMR2                @ 0xFCC;
// bit and bitfield definitions

// Register: T1CON
static volatile unsigned char           T1CON               @ 0xFCD;
// bit and bitfield definitions
static volatile bit TMR1ON              @ ((unsigned)&T1CON*8)+0;
//static volatile bit RD16               @ ((unsigned)&T1CON*8)+1;
static volatile bit nT1SYNC             @ ((unsigned)&T1CON*8)+2;
//static volatile bit SOSCEN             @ ((unsigned)&T1CON*8)+3;
static volatile bit T1CKPS0             @ ((unsigned)&T1CON*8)+4;
static volatile bit T1CKPS1             @ ((unsigned)&T1CON*8)+5;
static volatile bit TMR1CS0             @ ((unsigned)&T1CON*8)+6;
static volatile bit TMR1CS1             @ ((unsigned)&T1CON*8)+7;

// Register: TMR1L
static volatile unsigned char           TMR1L               @ 0xFCE;
// bit and bitfield definitions

// Register: TMR1H
static volatile unsigned char           TMR1H               @ 0xFCF;
// bit and bitfield definitions

// Register: TMR1
static volatile unsigned int            TMR1                @ 0xFCE;

// Register: RCON
static volatile unsigned char           RCON                @ 0xFD0;
// bit and bitfield definitions
static volatile bit nBOR                @ ((unsigned)&RCON*8)+0;
static volatile bit nPOR                @ ((unsigned)&RCON*8)+1;
static volatile bit nPD                 @ ((unsigned)&RCON*8)+2;
static volatile bit nTO                 @ ((unsigned)&RCON*8)+3;
static volatile bit nRI                 @ ((unsigned)&RCON*8)+4;
static volatile bit nCM                 @ ((unsigned)&RCON*8)+5;
static volatile bit SBOREN              @ ((unsigned)&RCON*8)+6;
static volatile bit IPEN                @ ((unsigned)&RCON*8)+7;
static volatile bit BOR                 @ ((unsigned)&RCON*8)+0;
static volatile bit POR                 @ ((unsigned)&RCON*8)+1;
static volatile bit PD                  @ ((unsigned)&RCON*8)+2;
static volatile bit TO                  @ ((unsigned)&RCON*8)+3;
static volatile bit RI                  @ ((unsigned)&RCON*8)+4;
static volatile bit CM                  @ ((unsigned)&RCON*8)+5;

// Register: WDTCON
static volatile unsigned char           WDTCON              @ 0xFD1;
// bit and bitfield definitions
static volatile bit SWDTEN              @ ((unsigned)&WDTCON*8)+0;
static volatile bit ULPSINK             @ ((unsigned)&WDTCON*8)+1;
static volatile bit ULPEN               @ ((unsigned)&WDTCON*8)+2;
static volatile bit SRETEN              @ ((unsigned)&WDTCON*8)+4;
static volatile bit ULPLVL              @ ((unsigned)&WDTCON*8)+5;
static volatile bit REGSLP              @ ((unsigned)&WDTCON*8)+7;
static volatile bit SWDTE               @ ((unsigned)&WDTCON*8)+0;

// Register: IPR5
static volatile unsigned char           IPR5                @ 0xFD2;
// bit and bitfield definitions
static volatile bit TMR4IP              @ ((unsigned)&IPR5*8)+0;
static volatile bit TMR5IP              @ ((unsigned)&IPR5*8)+1;
static volatile bit TMR6IP              @ ((unsigned)&IPR5*8)+2;
static volatile bit TMR8IP              @ ((unsigned)&IPR5*8)+4;
//static volatile bit CCH0               @ ((unsigned)&IPR5*8)+0;
//static volatile bit CCH1               @ ((unsigned)&IPR5*8)+1;
//static volatile bit EVPOL0             @ ((unsigned)&IPR5*8)+3;
//static volatile bit EVPOL1             @ ((unsigned)&IPR5*8)+4;

// Register: OSCCON
static volatile unsigned char           OSCCON              @ 0xFD3;
// bit and bitfield definitions
static volatile bit HFIOFS              @ ((unsigned)&OSCCON*8)+2;
static volatile bit OSTS                @ ((unsigned)&OSCCON*8)+3;
static volatile bit IDLEN               @ ((unsigned)&OSCCON*8)+7;
static volatile bit SCS0                @ ((unsigned)&OSCCON*8)+0;
static volatile bit SCS1                @ ((unsigned)&OSCCON*8)+1;
static volatile bit IRCF0               @ ((unsigned)&OSCCON*8)+4;
static volatile bit IRCF1               @ ((unsigned)&OSCCON*8)+5;
static volatile bit IRCF2               @ ((unsigned)&OSCCON*8)+6;

// Register: SPBRGH1
static volatile unsigned char           SPBRGH1             @ 0xFD4;
// bit and bitfield definitions

// Register: T0CON
static volatile unsigned char           T0CON               @ 0xFD5;
// bit and bitfield definitions
static volatile bit PSA                 @ ((unsigned)&T0CON*8)+3;
static volatile bit T0SE                @ ((unsigned)&T0CON*8)+4;
static volatile bit T0CS                @ ((unsigned)&T0CON*8)+5;
static volatile bit T08BIT              @ ((unsigned)&T0CON*8)+6;
static volatile bit TMR0ON              @ ((unsigned)&T0CON*8)+7;
static volatile bit T0PS0               @ ((unsigned)&T0CON*8)+0;
static volatile bit T0PS1               @ ((unsigned)&T0CON*8)+1;
static volatile bit T0PS2               @ ((unsigned)&T0CON*8)+2;

// Register: TMR0L
static volatile unsigned char           TMR0L               @ 0xFD6;
// bit and bitfield definitions

// Register: TMR0H
static volatile unsigned char           TMR0H               @ 0xFD7;
// bit and bitfield definitions

// Register: TMR0
static volatile unsigned int            TMR0                @ 0xFD6;

// Register: STATUS
static volatile unsigned char           STATUS              @ 0xFD8;
// bit and bitfield definitions
static volatile bit CARRY               @ ((unsigned)&STATUS*8)+0;
static volatile bit DC                  @ ((unsigned)&STATUS*8)+1;
static volatile bit ZERO                @ ((unsigned)&STATUS*8)+2;
static volatile bit OV                  @ ((unsigned)&STATUS*8)+3;
static volatile bit N                   @ ((unsigned)&STATUS*8)+4;

// Register: FSR2L
static volatile unsigned char           FSR2L               @ 0xFD9;
// bit and bitfield definitions

// Register: FSR2H
static volatile unsigned char           FSR2H               @ 0xFDA;

// Register: FSR2
static volatile unsigned int            FSR2                @ 0xFD9;

// Register: PLUSW2
static volatile unsigned char           PLUSW2              @ 0xFDB;
// bit and bitfield definitions

// Register: PREINC2
static volatile unsigned char           PREINC2             @ 0xFDC;
// bit and bitfield definitions

// Register: POSTDEC2
static volatile unsigned char           POSTDEC2            @ 0xFDD;
// bit and bitfield definitions

// Register: POSTINC2
static volatile unsigned char           POSTINC2            @ 0xFDE;
// bit and bitfield definitions

// Register: INDF2
static volatile unsigned char           INDF2               @ 0xFDF;
// bit and bitfield definitions

// Register: BSR
static volatile unsigned char           BSR                 @ 0xFE0;

// Register: FSR1L
static volatile unsigned char           FSR1L               @ 0xFE1;
// bit and bitfield definitions

// Register: FSR1H
static volatile unsigned char           FSR1H               @ 0xFE2;

// Register: FSR1
static volatile unsigned int            FSR1                @ 0xFE1;

// Register: PLUSW1
static volatile unsigned char           PLUSW1              @ 0xFE3;
// bit and bitfield definitions

// Register: PREINC1
static volatile unsigned char           PREINC1             @ 0xFE4;
// bit and bitfield definitions

// Register: POSTDEC1
static volatile unsigned char           POSTDEC1            @ 0xFE5;
// bit and bitfield definitions

// Register: POSTINC1
static volatile unsigned char           POSTINC1            @ 0xFE6;
// bit and bitfield definitions

// Register: INDF1
static volatile unsigned char           INDF1               @ 0xFE7;
// bit and bitfield definitions

// Register: WREG
static volatile unsigned char           WREG                @ 0xFE8;
// bit and bitfield definitions
// bit and bitfield definitions

// Register: FSR0L
static volatile unsigned char           FSR0L               @ 0xFE9;
// bit and bitfield definitions

// Register: FSR0H
static volatile unsigned char           FSR0H               @ 0xFEA;

// Register: FSR0
static volatile unsigned int            FSR0                @ 0xFE9;

// Register: PLUSW0
static volatile unsigned char           PLUSW0              @ 0xFEB;
// bit and bitfield definitions

// Register: PREINC0
static volatile unsigned char           PREINC0             @ 0xFEC;
// bit and bitfield definitions

// Register: POSTDEC0
static volatile unsigned char           POSTDEC0            @ 0xFED;
// bit and bitfield definitions

// Register: POSTINC0
static volatile unsigned char           POSTINC0            @ 0xFEE;
// bit and bitfield definitions

// Register: INDF0
static volatile unsigned char           INDF0               @ 0xFEF;
// bit and bitfield definitions

// Register: INTCON3
static volatile unsigned char           INTCON3             @ 0xFF0;
// bit and bitfield definitions
static volatile bit INT1IF              @ ((unsigned)&INTCON3*8)+0;
static volatile bit INT2IF              @ ((unsigned)&INTCON3*8)+1;
static volatile bit INT3IF              @ ((unsigned)&INTCON3*8)+2;
static volatile bit INT1IE              @ ((unsigned)&INTCON3*8)+3;
static volatile bit INT2IE              @ ((unsigned)&INTCON3*8)+4;
static volatile bit INT3IE              @ ((unsigned)&INTCON3*8)+5;
static volatile bit INT1IP              @ ((unsigned)&INTCON3*8)+6;
static volatile bit INT2IP              @ ((unsigned)&INTCON3*8)+7;
static volatile bit INT1F               @ ((unsigned)&INTCON3*8)+0;
static volatile bit INT2F               @ ((unsigned)&INTCON3*8)+1;
static volatile bit INT3F               @ ((unsigned)&INTCON3*8)+2;
static volatile bit INT1E               @ ((unsigned)&INTCON3*8)+3;
static volatile bit INT2E               @ ((unsigned)&INTCON3*8)+4;
static volatile bit INT3E               @ ((unsigned)&INTCON3*8)+5;
static volatile bit INT1P               @ ((unsigned)&INTCON3*8)+6;
static volatile bit INT2P               @ ((unsigned)&INTCON3*8)+7;

// Register: INTCON2
static volatile unsigned char           INTCON2             @ 0xFF1;
// bit and bitfield definitions
static volatile bit RBIP                @ ((unsigned)&INTCON2*8)+0;
static volatile bit INT3IP              @ ((unsigned)&INTCON2*8)+1;
static volatile bit TMR0IP              @ ((unsigned)&INTCON2*8)+2;
static volatile bit INTEDG3             @ ((unsigned)&INTCON2*8)+3;
static volatile bit INTEDG2             @ ((unsigned)&INTCON2*8)+4;
static volatile bit INTEDG1             @ ((unsigned)&INTCON2*8)+5;
static volatile bit INTEDG0             @ ((unsigned)&INTCON2*8)+6;
static volatile bit nRBPU               @ ((unsigned)&INTCON2*8)+7;
static volatile bit INT3P               @ ((unsigned)&INTCON2*8)+1;
static volatile bit T0IP                @ ((unsigned)&INTCON2*8)+2;
static volatile bit RBPU                @ ((unsigned)&INTCON2*8)+7;

// Register: INTCON
static volatile unsigned char           INTCON              @ 0xFF2;
// bit and bitfield definitions
static volatile bit RBIF                @ ((unsigned)&INTCON*8)+0;
static volatile bit INT0IF              @ ((unsigned)&INTCON*8)+1;
static volatile bit TMR0IF              @ ((unsigned)&INTCON*8)+2;
static volatile bit RBIE                @ ((unsigned)&INTCON*8)+3;
static volatile bit INT0IE              @ ((unsigned)&INTCON*8)+4;
static volatile bit TMR0IE              @ ((unsigned)&INTCON*8)+5;
static volatile bit PEIE_GIEL           @ ((unsigned)&INTCON*8)+6;
static volatile bit GIE_GIEH            @ ((unsigned)&INTCON*8)+7;
static volatile bit INT0F              @ ((unsigned)&INTCON*8)+1;
static volatile bit T0IF               @ ((unsigned)&INTCON*8)+2;
static volatile bit INT0E              @ ((unsigned)&INTCON*8)+4;
static volatile bit T0IE               @ ((unsigned)&INTCON*8)+5;
static volatile bit PEIE               @ ((unsigned)&INTCON*8)+6;
static volatile bit GIE                @ ((unsigned)&INTCON*8)+7;
static volatile bit GIEL               @ ((unsigned)&INTCON*8)+6;
static volatile bit GIEH               @ ((unsigned)&INTCON*8)+7;
////static volatile bit INT0F              @ ((unsigned)&INTCON*8)+1;
////static volatile bit T0IF               @ ((unsigned)&INTCON*8)+2;
////static volatile bit INT0E              @ ((unsigned)&INTCON*8)+4;
////static volatile bit T0IE               @ ((unsigned)&INTCON*8)+5;
////static volatile bit PEIE               @ ((unsigned)&INTCON*8)+6;
////static volatile bit GIE                @ ((unsigned)&INTCON*8)+7;
////static volatile bit GIEL               @ ((unsigned)&INTCON*8)+6;
////static volatile bit GIEH               @ ((unsigned)&INTCON*8)+7;

// Register: PRODL
static volatile unsigned char           PRODL               @ 0xFF3;
// bit and bitfield definitions

// Register: PRODH
static volatile unsigned char           PRODH               @ 0xFF4;
// bit and bitfield definitions

// Register: PROD
static volatile unsigned int            PROD                @ 0xFF3;

// Register: TABLAT
static volatile unsigned char           TABLAT              @ 0xFF5;
// Register: TBLPTR
static volatile unsigned int TBLPTR              @ 0xFF6;
// bit and bitfield definitions
// bit and bitfield definitions
//static volatile bit ACSS               @ ((unsigned)&TBLPTR*8)+21;

// Register: TBLPTRL
static volatile unsigned char           TBLPTRL             @ 0xFF6;
// bit and bitfield definitions

// Register: TBLPTRH
static volatile unsigned char           TBLPTRH             @ 0xFF7;
// bit and bitfield definitions

// Register: TBLPTRU
static volatile unsigned char           TBLPTRU             @ 0xFF8;
// bit and bitfield definitions
//static volatile bit ACSS               @ ((unsigned)&TBLPTRU*8)+5;

// bit and bitfield definitions

// Register: PCL
static volatile unsigned char           PCL                 @ 0xFF9;
// bit and bitfield definitions

// Register: PCLATH
static volatile unsigned char           PCLATH              @ 0xFFA;
// bit and bitfield definitions

// Register: PCLATU
static volatile unsigned char           PCLATU              @ 0xFFB;

// Register: PCLAT
static volatile unsigned int PCLAT               @ 0xFF9;

// Register: STKPTR
static volatile unsigned char           STKPTR              @ 0xFFC;
// bit and bitfield definitions
static volatile bit STKUNF              @ ((unsigned)&STKPTR*8)+6;
static volatile bit STKFUL              @ ((unsigned)&STKPTR*8)+7;
static volatile bit SP0                 @ ((unsigned)&STKPTR*8)+0;
static volatile bit SP1                 @ ((unsigned)&STKPTR*8)+1;
static volatile bit SP2                 @ ((unsigned)&STKPTR*8)+2;
static volatile bit SP3                 @ ((unsigned)&STKPTR*8)+3;
static volatile bit SP4                 @ ((unsigned)&STKPTR*8)+4;
static volatile bit STKOVF              @ ((unsigned)&STKPTR*8)+7;

// Register: TOSL
static volatile unsigned char           TOSL                @ 0xFFD;
// bit and bitfield definitions

// Register: TOSH
static volatile unsigned char           TOSH                @ 0xFFE;
// bit and bitfield definitions

// Register: TOSU
static volatile unsigned char           TOSU                @ 0xFFF;

// Register: TOS
static volatile unsigned int TOS                 @ 0xFFD;

// Register: TMR0_Internal
static volatile unsigned int            TMR0_Internal       @ 0x1000;

// Register: TMR0_Prescale
static volatile unsigned char           TMR0_Prescale       @ 0x1002;
// bit and bitfield definitions

// Register: TMR1_Internal
static volatile unsigned int            TMR1_Internal       @ 0x1003;

// Register: TMR1_Prescale
static volatile unsigned char           TMR1_Prescale       @ 0x1005;
// bit and bitfield definitions

// Register: TMR2_Prescale
static volatile unsigned char           TMR2_Prescale       @ 0x1006;
// bit and bitfield definitions

// Register: TMR3_Internal
static volatile unsigned int            TMR3_Internal       @ 0x1007;

// Register: TMR3_Prescale
static volatile unsigned char           TMR3_Prescale       @ 0x1009;
// bit and bitfield definitions

// Register: TMR4_Prescale
static volatile unsigned char           TMR4_Prescale       @ 0x100A;
// bit and bitfield definitions

// Register: TMR5_Internal
static volatile unsigned char           TMR5_Internal       @ 0x100B;
// bit and bitfield definitions

// Register: TMR5_Prescale
static volatile unsigned char           TMR5_Prescale       @ 0x100C;
// bit and bitfield definitions

// Register: TMR6_Prescale
static volatile unsigned char           TMR6_Prescale       @ 0x100D;
// bit and bitfield definitions

// Register: TMR8_Prescale
static volatile unsigned char           TMR8_Prescale       @ 0x100E;
// bit and bitfield definitions


#endif
